Class: Google::Apis::WorkloadmanagerV1::AgentCommand
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::AgentCommand
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
An AgentCommand specifies a one-time executable program for the agent to run.
Instance Attribute Summary collapse
-
#command ⇒ String
The name of the agent one-time executable that will be invoked.
-
#parameters ⇒ Hash<String,String>
A map of key/value pairs that can be used to specify additional one-time executable settings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AgentCommand
constructor
A new instance of AgentCommand.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AgentCommand
Returns a new instance of AgentCommand.
211 212 213 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 211 def initialize(**args) update!(**args) end |
Instance Attribute Details
#command ⇒ String
The name of the agent one-time executable that will be invoked.
Corresponds to the JSON property command
203 204 205 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 203 def command @command end |
#parameters ⇒ Hash<String,String>
A map of key/value pairs that can be used to specify additional one-time
executable settings.
Corresponds to the JSON property parameters
209 210 211 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 209 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
216 217 218 219 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 216 def update!(**args) @command = args[:command] if args.key?(:command) @parameters = args[:parameters] if args.key?(:parameters) end |