Class: Google::Apis::WorkloadmanagerV1::AgentStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

The schema of agent status data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentStatus

Returns a new instance of AgentStatus.



342
343
344
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 342

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_nameString

Output only. The name of the agent. Corresponds to the JSON property agentName

Returns:

  • (String)


280
281
282
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 280

def agent_name
  @agent_name
end

#available_versionString

Output only. The available version of the agent in artifact registry. Corresponds to the JSON property availableVersion

Returns:

  • (String)


285
286
287
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 285

def available_version
  @available_version
end

#cloud_api_access_full_scopes_grantedString

Output only. Whether the agent has full access to Cloud APIs. Corresponds to the JSON property cloudApiAccessFullScopesGranted

Returns:

  • (String)


290
291
292
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 290

def cloud_api_access_full_scopes_granted
  @cloud_api_access_full_scopes_granted
end

#configuration_error_messageString

Output only. The error message for the agent configuration if invalid. Corresponds to the JSON property configurationErrorMessage

Returns:

  • (String)


295
296
297
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 295

def configuration_error_message
  @configuration_error_message
end

#configuration_file_pathString

Output only. The path to the agent configuration file. Corresponds to the JSON property configurationFilePath

Returns:

  • (String)


300
301
302
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 300

def configuration_file_path
  @configuration_file_path
end

#configuration_validString

Output only. Whether the agent configuration is valid. Corresponds to the JSON property configurationValid

Returns:

  • (String)


305
306
307
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 305

def configuration_valid
  @configuration_valid
end

#installed_versionString

Output only. The installed version of the agent on the host. Corresponds to the JSON property installedVersion

Returns:

  • (String)


310
311
312
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 310

def installed_version
  @installed_version
end

#instance_uriString

Output only. The URI of the instance. Format: projects//zones//instances/ Corresponds to the JSON property instanceUri

Returns:

  • (String)


315
316
317
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 315

def instance_uri
  @instance_uri
end

#kernel_versionGoogle::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesKernelVersion

KernelVersion encapsulates the kernel version data for the system. Corresponds to the JSON property kernelVersion



320
321
322
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 320

def kernel_version
  @kernel_version
end

#referencesArray<Google::Apis::WorkloadmanagerV1::AgentStatusReference>

Output only. Optional references to public documentation. Corresponds to the JSON property references



325
326
327
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 325

def references
  @references
end

#servicesArray<Google::Apis::WorkloadmanagerV1::AgentStatusServiceStatus>

Output only. The services (process metrics, host metrics, etc.). Corresponds to the JSON property services



330
331
332
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 330

def services
  @services
end

#systemd_service_enabledString

Output only. Whether the agent service is enabled in systemd. Corresponds to the JSON property systemdServiceEnabled

Returns:

  • (String)


335
336
337
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 335

def systemd_service_enabled
  @systemd_service_enabled
end

#systemd_service_runningString

Output only. Whether the agent service is running in systemd. Corresponds to the JSON property systemdServiceRunning

Returns:

  • (String)


340
341
342
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 340

def systemd_service_running
  @systemd_service_running
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 347

def update!(**args)
  @agent_name = args[:agent_name] if args.key?(:agent_name)
  @available_version = args[:available_version] if args.key?(:available_version)
  @cloud_api_access_full_scopes_granted = args[:cloud_api_access_full_scopes_granted] if args.key?(:cloud_api_access_full_scopes_granted)
  @configuration_error_message = args[:configuration_error_message] if args.key?(:configuration_error_message)
  @configuration_file_path = args[:configuration_file_path] if args.key?(:configuration_file_path)
  @configuration_valid = args[:configuration_valid] if args.key?(:configuration_valid)
  @installed_version = args[:installed_version] if args.key?(:installed_version)
  @instance_uri = args[:instance_uri] if args.key?(:instance_uri)
  @kernel_version = args[:kernel_version] if args.key?(:kernel_version)
  @references = args[:references] if args.key?(:references)
  @services = args[:services] if args.key?(:services)
  @systemd_service_enabled = args[:systemd_service_enabled] if args.key?(:systemd_service_enabled)
  @systemd_service_running = args[:systemd_service_running] if args.key?(:systemd_service_running)
end