Class: Google::Apis::WorkloadmanagerV1::AgentStatusServiceStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

The status of a service (process metrics, host metrics, etc.).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentStatusServiceStatus

Returns a new instance of AgentStatusServiceStatus.



487
488
489
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_valuesArray<Google::Apis::WorkloadmanagerV1::AgentStatusConfigValue>

Output only. The configuration values for the service. Corresponds to the JSON property configValues



454
455
456
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 454

def config_values
  @config_values
end

#error_messageString

Output only. The error message for the service if it is not fully functional. Corresponds to the JSON property errorMessage

Returns:

  • (String)


459
460
461
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 459

def error_message
  @error_message
end

#fully_functionalString

Output only. Whether the service is fully functional (all checks passed). Corresponds to the JSON property fullyFunctional

Returns:

  • (String)


464
465
466
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 464

def fully_functional
  @fully_functional
end

#iam_permissionsArray<Google::Apis::WorkloadmanagerV1::AgentStatusIamPermission>

Output only. The permissions required for the service. Corresponds to the JSON property iamPermissions



469
470
471
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 469

def iam_permissions
  @iam_permissions
end

#nameString

Output only. The name of the service. Corresponds to the JSON property name

Returns:

  • (String)


474
475
476
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 474

def name
  @name
end

#stateString

Output only. The state of the service (enabled or disabled in the configuration). Corresponds to the JSON property state

Returns:

  • (String)


480
481
482
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 480

def state
  @state
end

#unspecified_state_messageString

Output only. The message to display when the service state is unspecified. Corresponds to the JSON property unspecifiedStateMessage

Returns:

  • (String)


485
486
487
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 485

def unspecified_state_message
  @unspecified_state_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



492
493
494
495
496
497
498
499
500
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 492

def update!(**args)
  @config_values = args[:config_values] if args.key?(:config_values)
  @error_message = args[:error_message] if args.key?(:error_message)
  @fully_functional = args[:fully_functional] if args.key?(:fully_functional)
  @iam_permissions = args[:iam_permissions] if args.key?(:iam_permissions)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @unspecified_state_message = args[:unspecified_state_message] if args.key?(:unspecified_state_message)
end