Class: Google::Apis::WorkloadmanagerV1::AppDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Message for SAP instance details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppDetails

Returns a new instance of AppDetails.



589
590
591
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_instance_idString

Optional. Instance ID for app. Corresponds to the JSON property appInstanceId

Returns:

  • (String)


510
511
512
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 510

def app_instance_id
  @app_instance_id
end

#app_service_accountString

Application service account. Let customers bring their own service account for the application. Corresponds to the JSON property appServiceAccount

Returns:

  • (String)


516
517
518
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 516

def 
  @app_service_account
end

#app_vm_namesArray<String>

Optional. Customized VM names. Corresponds to the JSON property appVmNames

Returns:

  • (Array<String>)


521
522
523
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 521

def app_vm_names
  @app_vm_names
end

#ascs_imageString

Required. Image for the ASCS server. Corresponds to the JSON property ascsImage

Returns:

  • (String)


526
527
528
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 526

def ascs_image
  @ascs_image
end

#ascs_instance_idString

Optional. Instance ID for ASCS. Corresponds to the JSON property ascsInstanceId

Returns:

  • (String)


531
532
533
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 531

def ascs_instance_id
  @ascs_instance_id
end

#ascs_machine_typeString

Required. ASCS machine type. Corresponds to the JSON property ascsMachineType

Returns:

  • (String)


536
537
538
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 536

def ascs_machine_type
  @ascs_machine_type
end

#ascs_service_accountString

ASCS service account. Let customers bring their own service account for ASCS. Corresponds to the JSON property ascsServiceAccount

Returns:

  • (String)


541
542
543
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 541

def 
  @ascs_service_account
end

#ascs_vmString

Optional. ASCS VM name. Corresponds to the JSON property ascsVm

Returns:

  • (String)


546
547
548
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 546

def ascs_vm
  @ascs_vm
end

#ers_instance_idString

Optional. Instance ID for ERS. Corresponds to the JSON property ersInstanceId

Returns:

  • (String)


551
552
553
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 551

def ers_instance_id
  @ers_instance_id
end

#ers_vmString

Optional. ERS VM name. Corresponds to the JSON property ersVm

Returns:

  • (String)


556
557
558
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 556

def ers_vm
  @ers_vm
end

#imageString

Required. Image for the app server and ASCS server. Corresponds to the JSON property image

Returns:

  • (String)


561
562
563
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 561

def image
  @image
end

#machine_typeString

Required. Machine type. Corresponds to the JSON property machineType

Returns:

  • (String)


566
567
568
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 566

def machine_type
  @machine_type
end

#secret_manager_secretString

Required. Secret Manager secret. Corresponds to the JSON property secretManagerSecret

Returns:

  • (String)


571
572
573
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 571

def secret_manager_secret
  @secret_manager_secret
end

#shared_storageString

Optional. Storage location. Corresponds to the JSON property sharedStorage

Returns:

  • (String)


576
577
578
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 576

def shared_storage
  @shared_storage
end

#sidString

Required. The SAP SID is a three-digit server-specific unique identification code. Corresponds to the JSON property sid

Returns:

  • (String)


582
583
584
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 582

def sid
  @sid
end

#vms_multiplierFixnum

Required. VMs multiplier. Corresponds to the JSON property vmsMultiplier

Returns:

  • (Fixnum)


587
588
589
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 587

def vms_multiplier
  @vms_multiplier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 594

def update!(**args)
  @app_instance_id = args[:app_instance_id] if args.key?(:app_instance_id)
  @app_service_account = args[:app_service_account] if args.key?(:app_service_account)
  @app_vm_names = args[:app_vm_names] if args.key?(:app_vm_names)
  @ascs_image = args[:ascs_image] if args.key?(:ascs_image)
  @ascs_instance_id = args[:ascs_instance_id] if args.key?(:ascs_instance_id)
  @ascs_machine_type = args[:ascs_machine_type] if args.key?(:ascs_machine_type)
  @ascs_service_account = args[:ascs_service_account] if args.key?(:ascs_service_account)
  @ascs_vm = args[:ascs_vm] if args.key?(:ascs_vm)
  @ers_instance_id = args[:ers_instance_id] if args.key?(:ers_instance_id)
  @ers_vm = args[:ers_vm] if args.key?(:ers_vm)
  @image = args[:image] if args.key?(:image)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @secret_manager_secret = args[:secret_manager_secret] if args.key?(:secret_manager_secret)
  @shared_storage = args[:shared_storage] if args.key?(:shared_storage)
  @sid = args[:sid] if args.key?(:sid)
  @vms_multiplier = args[:vms_multiplier] if args.key?(:vms_multiplier)
end