Class: Google::Apis::WorkloadmanagerV1::Database

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Database details

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Database

Returns a new instance of Database.



841
842
843
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 841

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disk_typeString

Required. disk_type Corresponds to the JSON property diskType

Returns:

  • (String)


785
786
787
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 785

def disk_type
  @disk_type
end

#floating_ip_addressString

Optional. only useful for Linux High Availability setup Corresponds to the JSON property floatingIpAddress

Returns:

  • (String)


790
791
792
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 790

def floating_ip_address
  @floating_ip_address
end

#machine_typeString

Required. machine type Corresponds to the JSON property machineType

Returns:

  • (String)


795
796
797
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 795

def machine_type
  @machine_type
end

#secondary_sole_tenant_nodeString

Optional. the name of a secondary-sole-tenant node/node group Corresponds to the JSON property secondarySoleTenantNode

Returns:

  • (String)


800
801
802
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 800

def secondary_sole_tenant_node
  @secondary_sole_tenant_node
end

#secondary_sole_tenant_node_typeString

Optional. the type of a secondary-sole-tenant node/node group e.g. compute. googleapis.com/node-name Corresponds to the JSON property secondarySoleTenantNodeType

Returns:

  • (String)


806
807
808
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 806

def secondary_sole_tenant_node_type
  @secondary_sole_tenant_node_type
end

#secret_manager_secretString

Required. secret_manager_secret Corresponds to the JSON property secretManagerSecret

Returns:

  • (String)


811
812
813
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 811

def secret_manager_secret
  @secret_manager_secret
end

#smtBoolean Also known as: smt?

Required. whether simultaneous multithreading is enabled or not Corresponds to the JSON property smt

Returns:

  • (Boolean)


816
817
818
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 816

def smt
  @smt
end

#sole_tenant_nodeString

Optional. the name of a primary sole-tenant node/node group Corresponds to the JSON property soleTenantNode

Returns:

  • (String)


822
823
824
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 822

def sole_tenant_node
  @sole_tenant_node
end

#sole_tenant_node_typeString

Optional. the type of a primary sole-tenant node/node group e.g. compute. googleapis.com/node-name Corresponds to the JSON property soleTenantNodeType

Returns:

  • (String)


828
829
830
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 828

def sole_tenant_node_type
  @sole_tenant_node_type
end

#tempdb_on_ssdBoolean Also known as: tempdb_on_ssd?

Required. whether to have TempDB on local SSD Corresponds to the JSON property tempdbOnSsd

Returns:

  • (Boolean)


833
834
835
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 833

def tempdb_on_ssd
  @tempdb_on_ssd
end

#tenancy_modelString

Required. SHARED or SOLE_TENANT Corresponds to the JSON property tenancyModel

Returns:

  • (String)


839
840
841
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 839

def tenancy_model
  @tenancy_model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



846
847
848
849
850
851
852
853
854
855
856
857
858
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 846

def update!(**args)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @floating_ip_address = args[:floating_ip_address] if args.key?(:floating_ip_address)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @secondary_sole_tenant_node = args[:secondary_sole_tenant_node] if args.key?(:secondary_sole_tenant_node)
  @secondary_sole_tenant_node_type = args[:secondary_sole_tenant_node_type] if args.key?(:secondary_sole_tenant_node_type)
  @secret_manager_secret = args[:secret_manager_secret] if args.key?(:secret_manager_secret)
  @smt = args[:smt] if args.key?(:smt)
  @sole_tenant_node = args[:sole_tenant_node] if args.key?(:sole_tenant_node)
  @sole_tenant_node_type = args[:sole_tenant_node_type] if args.key?(:sole_tenant_node_type)
  @tempdb_on_ssd = args[:tempdb_on_ssd] if args.key?(:tempdb_on_ssd)
  @tenancy_model = args[:tenancy_model] if args.key?(:tenancy_model)
end