Class: Google::Apis::WorkloadmanagerV1::Deployment
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::Deployment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
The Deployment object represents user intent for deploying a specific type of workload.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the deployment.
-
#name ⇒ String
The name of the deployment resource.
-
#sap_system_s4_config ⇒ Google::Apis::WorkloadmanagerV1::SapSystemS4Config
Message for SAP system workload.
-
#service_account ⇒ String
User-specified Service Account (SA) credentials to be used for Cloud Build.
-
#sql_server_workload ⇒ Google::Apis::WorkloadmanagerV1::SqlServerWorkload
Message for MS SQL workload.
-
#state ⇒ String
Output only.
-
#terraform_variables ⇒ Hash<String,Google::Apis::WorkloadmanagerV1::TerraformVariable>
Optional.
-
#update_time ⇒ String
Output only.
-
#worker_pool ⇒ String
Optional.
-
#workload_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Deployment
constructor
A new instance of Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Deployment
Returns a new instance of Deployment.
1025 1026 1027 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Create time stamp.
Corresponds to the JSON property createTime
962 963 964 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 962 def create_time @create_time end |
#description ⇒ String
Description of the deployment.
Corresponds to the JSON property description
967 968 969 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 967 def description @description end |
#name ⇒ String
The name of the deployment resource. The format is 'projects/project_id/
locations/location_id/deployments/deployment_id'.
Corresponds to the JSON property name
973 974 975 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 973 def name @name end |
#sap_system_s4_config ⇒ Google::Apis::WorkloadmanagerV1::SapSystemS4Config
Message for SAP system workload.
Corresponds to the JSON property sapSystemS4Config
978 979 980 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 978 def sap_system_s4_config @sap_system_s4_config end |
#service_account ⇒ String
User-specified Service Account (SA) credentials to be used for Cloud Build.
Format: projects/projectID/serviceAccounts/serviceAccount`The default
Cloud Build SA will be used initially if this field is not set during
deployment creation.
Corresponds to the JSON propertyserviceAccount`
986 987 988 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 986 def service_account @service_account end |
#sql_server_workload ⇒ Google::Apis::WorkloadmanagerV1::SqlServerWorkload
Message for MS SQL workload.
Corresponds to the JSON property sqlServerWorkload
991 992 993 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 991 def sql_server_workload @sql_server_workload end |
#state ⇒ String
Output only. Current state of the deployment.
Corresponds to the JSON property state
996 997 998 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 996 def state @state end |
#terraform_variables ⇒ Hash<String,Google::Apis::WorkloadmanagerV1::TerraformVariable>
Optional. terraform_variables represents all the Terraform variables for the
deployment workload. The key is the name of the Terraform variable, and the
value is the TerraformVariable. For example: "project_id": "input_value":
"string_value": "my-project-id" , "zone": "input_value": "string_value"
: "us-central1-a"
Corresponds to the JSON property terraformVariables
1005 1006 1007 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1005 def terraform_variables @terraform_variables end |
#update_time ⇒ String
Output only. Update time stamp.
Corresponds to the JSON property updateTime
1010 1011 1012 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1010 def update_time @update_time end |
#worker_pool ⇒ String
Optional. The user-specified Cloud Build worker pool resource in which the
Cloud Build job will execute. Format: projects/project/locations/location/
workerPools/workerPoolId`. If this field is unspecified, the default Cloud
Build worker pool will be used.
Corresponds to the JSON propertyworkerPool`
1018 1019 1020 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1018 def worker_pool @worker_pool end |
#workload_type ⇒ String
Optional. Workload type of the deployment.
Corresponds to the JSON property workloadType
1023 1024 1025 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1023 def workload_type @workload_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1030 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @sap_system_s4_config = args[:sap_system_s4_config] if args.key?(:sap_system_s4_config) @service_account = args[:service_account] if args.key?(:service_account) @sql_server_workload = args[:sql_server_workload] if args.key?(:sql_server_workload) @state = args[:state] if args.key?(:state) @terraform_variables = args[:terraform_variables] if args.key?(:terraform_variables) @update_time = args[:update_time] if args.key?(:update_time) @worker_pool = args[:worker_pool] if args.key?(:worker_pool) @workload_type = args[:workload_type] if args.key?(:workload_type) end |