Class: Google::Apis::WorkloadmanagerV1::Evaluation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Represents a Workload Manager Evaluation configuration. An Evaluation defines a set of rules to be validated against a scope of Cloud resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Evaluation

Returns a new instance of Evaluation.



1163
1164
1165
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_destinationGoogle::Apis::WorkloadmanagerV1::BigQueryDestination

BigQuery destination for evaluation results. Corresponds to the JSON property bigQueryDestination



1094
1095
1096
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1094

def big_query_destination
  @big_query_destination
end

#create_timeString

Output only. [Output only] Create time stamp. Corresponds to the JSON property createTime

Returns:

  • (String)


1099
1100
1101
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1099

def create_time
  @create_time
end

#custom_rules_bucketString

The Cloud Storage bucket name for custom rules. Corresponds to the JSON property customRulesBucket

Returns:

  • (String)


1104
1105
1106
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1104

def custom_rules_bucket
  @custom_rules_bucket
end

#descriptionString

Description of the Evaluation. Corresponds to the JSON property description

Returns:

  • (String)


1109
1110
1111
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1109

def description
  @description
end

#evaluation_typeString

Evaluation type. Corresponds to the JSON property evaluationType

Returns:

  • (String)


1114
1115
1116
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1114

def evaluation_type
  @evaluation_type
end

#kms_keyString

Optional. Immutable. Customer-managed encryption key name, in the format projects//locations//keyRings//cryptoKeys/. The key will be used for CMEK encryption of the evaluation resource. Corresponds to the JSON property kmsKey

Returns:

  • (String)


1121
1122
1123
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1121

def kms_key
  @kms_key
end

#labelsHash<String,String>

Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1126
1127
1128
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1126

def labels
  @labels
end

#nameString

Name of resource that has the form projects/project_id/locations/ location_id/evaluations/evaluation_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1132
1133
1134
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1132

def name
  @name
end

#resource_filterGoogle::Apis::WorkloadmanagerV1::ResourceFilter

Resource filter for an evaluation defining the scope of resources to be evaluated. Corresponds to the JSON property resourceFilter



1138
1139
1140
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1138

def resource_filter
  @resource_filter
end

#resource_statusGoogle::Apis::WorkloadmanagerV1::ResourceStatus

The lifecycle status of an Evaluation resource. Corresponds to the JSON property resourceStatus



1143
1144
1145
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1143

def resource_status
  @resource_status
end

#rule_namesArray<String>

The names of the rules used for this evaluation. Corresponds to the JSON property ruleNames

Returns:

  • (Array<String>)


1148
1149
1150
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1148

def rule_names
  @rule_names
end

#scheduleString

Crontab format schedule for scheduled evaluation, currently only supports the following fixed schedules: * 0 */1 * * * # Hourly * 0 */6 * * * # Every 6 hours * 0 */12 * * * # Every 12 hours * 0 0 */1 * * # Daily * 0 0 */7 * *

Weekly * 0 0 */14 * * # Every 14 days * 0 0 1 */1 * # Monthly

Corresponds to the JSON property schedule

Returns:

  • (String)


1156
1157
1158
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1156

def schedule
  @schedule
end

#update_timeString

Output only. [Output only] Update time stamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


1161
1162
1163
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1161

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1168

def update!(**args)
  @big_query_destination = args[:big_query_destination] if args.key?(:big_query_destination)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_rules_bucket = args[:custom_rules_bucket] if args.key?(:custom_rules_bucket)
  @description = args[:description] if args.key?(:description)
  @evaluation_type = args[:evaluation_type] if args.key?(:evaluation_type)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @resource_filter = args[:resource_filter] if args.key?(:resource_filter)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @rule_names = args[:rule_names] if args.key?(:rule_names)
  @schedule = args[:schedule] if args.key?(:schedule)
  @update_time = args[:update_time] if args.key?(:update_time)
end