Class: Google::Apis::WorkloadmanagerV1::ExternalDataSources

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

External data sources for an execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalDataSources

Returns a new instance of ExternalDataSources.



1368
1369
1370
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1368

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_typeString

Required. The asset type of the external data source. This can be a supported Cloud Asset Inventory asset type (see https://cloud.google.com/asset-inventory/ docs/supported-asset-types) to override the default asset type, or it can be a custom type defined by the user. Corresponds to the JSON property assetType

Returns:

  • (String)


1349
1350
1351
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1349

def asset_type
  @asset_type
end

#nameString

Optional. Name of external data source. The name will be used inside the rego/ sql to refer the external data. Corresponds to the JSON property name

Returns:

  • (String)


1355
1356
1357
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1355

def name
  @name
end

#typeString

Required. Type of external data source. Corresponds to the JSON property type

Returns:

  • (String)


1360
1361
1362
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1360

def type
  @type
end

#uriString

Required. URI of external data source. example of bq table project_ID. dataset_ID.table_ID. Corresponds to the JSON property uri

Returns:

  • (String)


1366
1367
1368
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1366

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1373
1374
1375
1376
1377
1378
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1373

def update!(**args)
  @asset_type = args[:asset_type] if args.key?(:asset_type)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @uri = args[:uri] if args.key?(:uri)
end