Class: Google::Apis::WorkloadmanagerV1::ListDeploymentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::ListDeploymentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
Message for response to listing Deployments
Instance Attribute Summary collapse
-
#deployments ⇒ Array<Google::Apis::WorkloadmanagerV1::Deployment>
The list of Deployment Corresponds to the JSON property
deployments. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDeploymentsResponse
constructor
A new instance of ListDeploymentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDeploymentsResponse
Returns a new instance of ListDeploymentsResponse.
1633 1634 1635 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1633 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployments ⇒ Array<Google::Apis::WorkloadmanagerV1::Deployment>
The list of Deployment
Corresponds to the JSON property deployments
1621 1622 1623 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1621 def deployments @deployments end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1626 1627 1628 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1626 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
1631 1632 1633 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1631 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1638 1639 1640 1641 1642 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1638 def update!(**args) @deployments = args[:deployments] if args.key?(:deployments) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |