Class: Google::Apis::WorkloadmanagerV1::ListDiscoveredProfilesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

List discovered profile Response returns discovered profiles from agents

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDiscoveredProfilesResponse

Returns a new instance of ListDiscoveredProfilesResponse.



1664
1665
1666
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1664

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Output only. A token identifying a page of results the server should return Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1652
1653
1654
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1652

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1657
1658
1659
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1657

def unreachable
  @unreachable
end

#workload_profilesArray<Google::Apis::WorkloadmanagerV1::WorkloadProfile>

Output only. The list of workload profiles Corresponds to the JSON property workloadProfiles



1662
1663
1664
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1662

def workload_profiles
  @workload_profiles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1669
1670
1671
1672
1673
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1669

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
  @workload_profiles = args[:workload_profiles] if args.key?(:workload_profiles)
end