Class: Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

A set of properties only present for an instance type resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SapDiscoveryResourceInstanceProperties

Returns a new instance of SapDiscoveryResourceInstanceProperties.



2994
2995
2996
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_instancesArray<Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesAppInstance>

Optional. App server instances on the host Corresponds to the JSON property appInstances



2956
2957
2958
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2956

def app_instances
  @app_instances
end

#cluster_instancesArray<String>

Optional. A list of instance URIs that are part of a cluster with this one. Corresponds to the JSON property clusterInstances

Returns:

  • (Array<String>)


2961
2962
2963
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2961

def cluster_instances
  @cluster_instances
end

#disk_mountsArray<Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesDiskMount>

Optional. Disk mounts on the instance. Corresponds to the JSON property diskMounts



2966
2967
2968
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2966

def disk_mounts
  @disk_mounts
end

#instance_numberFixnum

Optional. The VM's instance number. Corresponds to the JSON property instanceNumber

Returns:

  • (Fixnum)


2971
2972
2973
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2971

def instance_number
  @instance_number
end

#instance_roleString

Optional. Bitmask of instance role, a resource may have multiple roles at once. Corresponds to the JSON property instanceRole

Returns:

  • (String)


2976
2977
2978
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2976

def instance_role
  @instance_role
end

#is_dr_siteBoolean Also known as: is_dr_site?

Optional. Instance is part of a DR site. Corresponds to the JSON property isDrSite

Returns:

  • (Boolean)


2981
2982
2983
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2981

def is_dr_site
  @is_dr_site
end

#os_kernel_versionGoogle::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesKernelVersion

KernelVersion encapsulates the kernel version data for the system. Corresponds to the JSON property osKernelVersion



2987
2988
2989
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2987

def os_kernel_version
  @os_kernel_version
end

#virtual_hostnameString

Optional. A virtual hostname of the instance if it has one. Corresponds to the JSON property virtualHostname

Returns:

  • (String)


2992
2993
2994
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2992

def virtual_hostname
  @virtual_hostname
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2999

def update!(**args)
  @app_instances = args[:app_instances] if args.key?(:app_instances)
  @cluster_instances = args[:cluster_instances] if args.key?(:cluster_instances)
  @disk_mounts = args[:disk_mounts] if args.key?(:disk_mounts)
  @instance_number = args[:instance_number] if args.key?(:instance_number)
  @instance_role = args[:instance_role] if args.key?(:instance_role)
  @is_dr_site = args[:is_dr_site] if args.key?(:is_dr_site)
  @os_kernel_version = args[:os_kernel_version] if args.key?(:os_kernel_version)
  @virtual_hostname = args[:virtual_hostname] if args.key?(:virtual_hostname)
end