Class: Google::Apis::WorkloadmanagerV1::SapDiscoveryWorkloadProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

A set of properties describing an SAP workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SapDiscoveryWorkloadProperties

Returns a new instance of SapDiscoveryWorkloadProperties.



3155
3156
3157
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#product_versionsArray<Google::Apis::WorkloadmanagerV1::SapDiscoveryWorkloadPropertiesProductVersion>

Optional. List of SAP Products and their versions running on the system. Corresponds to the JSON property productVersions



3147
3148
3149
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3147

def product_versions
  @product_versions
end

#software_component_versionsArray<Google::Apis::WorkloadmanagerV1::SapDiscoveryWorkloadPropertiesSoftwareComponentProperties>

Optional. A list of SAP software components and their versions running on the system. Corresponds to the JSON property softwareComponentVersions



3153
3154
3155
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3153

def software_component_versions
  @software_component_versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3160
3161
3162
3163
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3160

def update!(**args)
  @product_versions = args[:product_versions] if args.key?(:product_versions)
  @software_component_versions = args[:software_component_versions] if args.key?(:software_component_versions)
end