Class: Google::Apis::WorkloadmanagerV1::SapSystemS4Config

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Message for SAP system workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SapSystemS4Config

Returns a new instance of SapSystemS4Config.



3327
3328
3329
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_stopping_for_updateBoolean Also known as: allow_stopping_for_update?

Corresponds to the JSON property allowStoppingForUpdate

Returns:

  • (Boolean)


3262
3263
3264
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3262

def allow_stopping_for_update
  @allow_stopping_for_update
end

#ansible_runner_service_accountString

Ansible runner service account. Let customers bring their own service account for the Ansible runner. Corresponds to the JSON property ansibleRunnerServiceAccount

Returns:

  • (String)


3269
3270
3271
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3269

def 
  @ansible_runner_service_account
end

#appGoogle::Apis::WorkloadmanagerV1::AppDetails

Message for SAP instance details. Corresponds to the JSON property app



3274
3275
3276
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3274

def app
  @app
end

#databaseGoogle::Apis::WorkloadmanagerV1::DatabaseDetails

Message for SAP instance details. Corresponds to the JSON property database



3279
3280
3281
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3279

def database
  @database
end

#deployment_modelString

Required. Supports non-HA and HA models. Corresponds to the JSON property deploymentModel

Returns:

  • (String)


3284
3285
3286
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3284

def deployment_model
  @deployment_model
end

#environment_typeString

Required. Deployment environment. Corresponds to the JSON property environmentType

Returns:

  • (String)


3289
3290
3291
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3289

def environment_type
  @environment_type
end

#gcp_project_idString

The project that infrastructure is deployed in. Currently only supports the same project where the deployment resource exists. Corresponds to the JSON property gcpProjectId

Returns:

  • (String)


3295
3296
3297
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3295

def gcp_project_id
  @gcp_project_id
end

#locationGoogle::Apis::WorkloadmanagerV1::LocationDetails

Message for SAP instance details. Corresponds to the JSON property location



3300
3301
3302
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3300

def location
  @location
end

#media_bucket_nameString

Required. Media bucket name. Corresponds to the JSON property mediaBucketName

Returns:

  • (String)


3305
3306
3307
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3305

def media_bucket_name
  @media_bucket_name
end

#sap_boot_disk_imageString

Optional. SAP boot disk image. Corresponds to the JSON property sapBootDiskImage

Returns:

  • (String)


3310
3311
3312
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3310

def sap_boot_disk_image
  @sap_boot_disk_image
end

#scaling_methodString

Required. Supports scale up and scale out. Corresponds to the JSON property scalingMethod

Returns:

  • (String)


3315
3316
3317
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3315

def scaling_method
  @scaling_method
end

#versionString

Required. SAP HANA version. Corresponds to the JSON property version

Returns:

  • (String)


3320
3321
3322
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3320

def version
  @version
end

#vm_prefixString

VM prefix. Corresponds to the JSON property vmPrefix

Returns:

  • (String)


3325
3326
3327
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3325

def vm_prefix
  @vm_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3332

def update!(**args)
  @allow_stopping_for_update = args[:allow_stopping_for_update] if args.key?(:allow_stopping_for_update)
  @ansible_runner_service_account = args[:ansible_runner_service_account] if args.key?(:ansible_runner_service_account)
  @app = args[:app] if args.key?(:app)
  @database = args[:database] if args.key?(:database)
  @deployment_model = args[:deployment_model] if args.key?(:deployment_model)
  @environment_type = args[:environment_type] if args.key?(:environment_type)
  @gcp_project_id = args[:gcp_project_id] if args.key?(:gcp_project_id)
  @location = args[:location] if args.key?(:location)
  @media_bucket_name = args[:media_bucket_name] if args.key?(:media_bucket_name)
  @sap_boot_disk_image = args[:sap_boot_disk_image] if args.key?(:sap_boot_disk_image)
  @scaling_method = args[:scaling_method] if args.key?(:scaling_method)
  @version = args[:version] if args.key?(:version)
  @vm_prefix = args[:vm_prefix] if args.key?(:vm_prefix)
end