Class: Google::Apis::WorkloadmanagerV1::SqlLocationDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Location and networking details for configuring SQL server workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlLocationDetails

Returns a new instance of SqlLocationDetails.



3591
3592
3593
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_zoneString

Optional. Create a new DNS zone when the field is empty. Only shown for Using an existing DNS. List of existing DNS zones. Terraform variable name: existing_dns_zone_name. Corresponds to the JSON property dnsZone

Returns:

  • (String)


3546
3547
3548
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3546

def dns_zone
  @dns_zone
end

#gcp_project_idString

Required. The project that infrastructure is deployed in. Currently only supports the same project where the deployment resource exists. Corresponds to the JSON property gcpProjectId

Returns:

  • (String)


3552
3553
3554
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3552

def gcp_project_id
  @gcp_project_id
end

#internet_accessString

Required. Internet Access. Corresponds to the JSON property internetAccess

Returns:

  • (String)


3557
3558
3559
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3557

def internet_access
  @internet_access
end

#networkString

Required. Network name. Corresponds to the JSON property network

Returns:

  • (String)


3562
3563
3564
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3562

def network
  @network
end

#primary_zoneString

Required. Primary zone. Corresponds to the JSON property primaryZone

Returns:

  • (String)


3567
3568
3569
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3567

def primary_zone
  @primary_zone
end

#regionString

Required. Region name. Corresponds to the JSON property region

Returns:

  • (String)


3572
3573
3574
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3572

def region
  @region
end

#secondary_zoneString

Optional. Secondary zone cannot be the same as primary_zone and is only for High Availability deployment mode. Corresponds to the JSON property secondaryZone

Returns:

  • (String)


3578
3579
3580
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3578

def secondary_zone
  @secondary_zone
end

#subnetworkString

Required. Subnetwork name. Corresponds to the JSON property subnetwork

Returns:

  • (String)


3583
3584
3585
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3583

def subnetwork
  @subnetwork
end

#tertiary_zoneString

Optional. Tertiary zone cannot be the same as primary_zone and secondary_zone, and it is only for High Availability deployment mode. Corresponds to the JSON property tertiaryZone

Returns:

  • (String)


3589
3590
3591
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3589

def tertiary_zone
  @tertiary_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3596
3597
3598
3599
3600
3601
3602
3603
3604
3605
3606
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3596

def update!(**args)
  @dns_zone = args[:dns_zone] if args.key?(:dns_zone)
  @gcp_project_id = args[:gcp_project_id] if args.key?(:gcp_project_id)
  @internet_access = args[:internet_access] if args.key?(:internet_access)
  @network = args[:network] if args.key?(:network)
  @primary_zone = args[:primary_zone] if args.key?(:primary_zone)
  @region = args[:region] if args.key?(:region)
  @secondary_zone = args[:secondary_zone] if args.key?(:secondary_zone)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @tertiary_zone = args[:tertiary_zone] if args.key?(:tertiary_zone)
end