Class: Google::Apis::WorkloadmanagerV1::SqlServerWorkload

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Message for MS SQL workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerWorkload

Returns a new instance of SqlServerWorkload.



3705
3706
3707
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_directoryGoogle::Apis::WorkloadmanagerV1::ActiveDirectory

Active Directory details. Corresponds to the JSON property activeDirectory



3616
3617
3618
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3616

def active_directory
  @active_directory
end

#compute_engine_service_accountString

Compute Engine service account. Let customers bring their own service account for Compute Engine. Corresponds to the JSON property computeEngineServiceAccount

Returns:

  • (String)


3622
3623
3624
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3622

def 
  @compute_engine_service_account
end

#databaseGoogle::Apis::WorkloadmanagerV1::Database

Database details. Corresponds to the JSON property database



3627
3628
3629
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3627

def database
  @database
end

#deployment_modelString

Required. HIGH_AVAILABILITY or SINGLE_INSTANCE. Corresponds to the JSON property deploymentModel

Returns:

  • (String)


3632
3633
3634
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3632

def deployment_model
  @deployment_model
end

#environment_typeString

Required. Deployment environment. Corresponds to the JSON property environmentType

Returns:

  • (String)


3637
3638
3639
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3637

def environment_type
  @environment_type
end

#fci_typeString

Optional. SHARED_DISK or S2D. Corresponds to the JSON property fciType

Returns:

  • (String)


3642
3643
3644
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3642

def fci_type
  @fci_type
end

#ha_typeString

Optional. AOAG or FCI. It is only needed for the High Availability deployment mode. Corresponds to the JSON property haType

Returns:

  • (String)


3648
3649
3650
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3648

def ha_type
  @ha_type
end

#is_sql_paygBoolean Also known as: is_sql_payg?

Required. SQL licensing type. Corresponds to the JSON property isSqlPayg

Returns:

  • (Boolean)


3653
3654
3655
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3653

def is_sql_payg
  @is_sql_payg
end

#locationGoogle::Apis::WorkloadmanagerV1::SqlLocationDetails

Location and networking details for configuring SQL server workload. Corresponds to the JSON property location



3659
3660
3661
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3659

def location
  @location
end

#media_bucketString

Required. Name of the media storing SQL server installation files. Corresponds to the JSON property mediaBucket

Returns:

  • (String)


3664
3665
3666
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3664

def media_bucket
  @media_bucket
end

#operating_system_typeString

Required. The type of the operating system the SQL server is going to run on top of. Corresponds to the JSON property operatingSystemType

Returns:

  • (String)


3670
3671
3672
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3670

def operating_system_type
  @operating_system_type
end

#os_imageString

Required. The image of the operating system. Corresponds to the JSON property osImage

Returns:

  • (String)


3675
3676
3677
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3675

def os_image
  @os_image
end

#os_image_typeString

Optional. OS image type. It's used to create boot disks for VM instances. When either Windows licensing type or SQL licensing type is BYOL, this option is disabled and defaults to a custom image. Corresponds to the JSON property osImageType

Returns:

  • (String)


3682
3683
3684
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3682

def os_image_type
  @os_image_type
end

#pacemakerGoogle::Apis::WorkloadmanagerV1::Pacemaker

Pacemaker configuration. Corresponds to the JSON property pacemaker



3687
3688
3689
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3687

def pacemaker
  @pacemaker
end

#sql_server_editionString

Optional. SQL Server Edition type, only applicable when the operating system is Linux. Corresponds to the JSON property sqlServerEdition

Returns:

  • (String)


3693
3694
3695
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3693

def sql_server_edition
  @sql_server_edition
end

#sql_server_versionString

Optional. 2017, 2019, or 2022. Corresponds to the JSON property sqlServerVersion

Returns:

  • (String)


3698
3699
3700
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3698

def sql_server_version
  @sql_server_version
end

#vm_prefixString

Required. Should be unique in the project. Corresponds to the JSON property vmPrefix

Returns:

  • (String)


3703
3704
3705
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3703

def vm_prefix
  @vm_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3710
3711
3712
3713
3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3710

def update!(**args)
  @active_directory = args[:active_directory] if args.key?(:active_directory)
  @compute_engine_service_account = args[:compute_engine_service_account] if args.key?(:compute_engine_service_account)
  @database = args[:database] if args.key?(:database)
  @deployment_model = args[:deployment_model] if args.key?(:deployment_model)
  @environment_type = args[:environment_type] if args.key?(:environment_type)
  @fci_type = args[:fci_type] if args.key?(:fci_type)
  @ha_type = args[:ha_type] if args.key?(:ha_type)
  @is_sql_payg = args[:is_sql_payg] if args.key?(:is_sql_payg)
  @location = args[:location] if args.key?(:location)
  @media_bucket = args[:media_bucket] if args.key?(:media_bucket)
  @operating_system_type = args[:operating_system_type] if args.key?(:operating_system_type)
  @os_image = args[:os_image] if args.key?(:os_image)
  @os_image_type = args[:os_image_type] if args.key?(:os_image_type)
  @pacemaker = args[:pacemaker] if args.key?(:pacemaker)
  @sql_server_edition = args[:sql_server_edition] if args.key?(:sql_server_edition)
  @sql_server_version = args[:sql_server_version] if args.key?(:sql_server_version)
  @vm_prefix = args[:vm_prefix] if args.key?(:vm_prefix)
end