Class: Google::Apis::WorkloadmanagerV1::SqlserverValidation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

A presentation of SQLServer workload insight. The schema of SqlServer workloads validation related data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlserverValidation

Returns a new instance of SqlserverValidation.



3758
3759
3760
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3758

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_versionString

Optional. The agent version collected this data point Corresponds to the JSON property agentVersion

Returns:

  • (String)


3739
3740
3741
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3739

def agent_version
  @agent_version
end

#instanceString

Required. The instance_name of the instance that the Insight data comes from. According to https://linter.aip.dev/122/name-suffix: field names should not use the _name suffix unless the field would be ambiguous without it. Corresponds to the JSON property instance

Returns:

  • (String)


3746
3747
3748
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3746

def instance
  @instance
end

#project_idString

Required. The project_id of the cloud project that the Insight data comes from. Corresponds to the JSON property projectId

Returns:

  • (String)


3751
3752
3753
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3751

def project_id
  @project_id
end

#validation_detailsArray<Google::Apis::WorkloadmanagerV1::SqlserverValidationValidationDetail>

Optional. A list of SqlServer validation metrics data. Corresponds to the JSON property validationDetails



3756
3757
3758
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3756

def validation_details
  @validation_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3763
3764
3765
3766
3767
3768
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3763

def update!(**args)
  @agent_version = args[:agent_version] if args.key?(:agent_version)
  @instance = args[:instance] if args.key?(:instance)
  @project_id = args[:project_id] if args.key?(:project_id)
  @validation_details = args[:validation_details] if args.key?(:validation_details)
end