Class: Google::Apis::WorkloadmanagerV1::SqlserverValidationValidationDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Message describing the Sqlserver validation metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlserverValidationValidationDetail

Returns a new instance of SqlserverValidationValidationDetail.



3801
3802
3803
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3801

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsArray<Google::Apis::WorkloadmanagerV1::SqlserverValidationDetails>

Required. Details wraps map that represents collected data names and values. Corresponds to the JSON property details



3794
3795
3796
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3794

def details
  @details
end

#typeString

Optional. The Sqlserver system that the validation data is from. Corresponds to the JSON property type

Returns:

  • (String)


3799
3800
3801
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3799

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3806
3807
3808
3809
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3806

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @type = args[:type] if args.key?(:type)
end