Class: Google::Apis::WorkloadmanagerV1::Summary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Execution summary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Summary

Returns a new instance of Summary.



3873
3874
3875
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failuresFixnum

Output only. Number of failures. Corresponds to the JSON property failures

Returns:

  • (Fixnum)


3861
3862
3863
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3861

def failures
  @failures
end

#new_failuresFixnum

Output only. Number of new failures compared to the previous execution. Corresponds to the JSON property newFailures

Returns:

  • (Fixnum)


3866
3867
3868
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3866

def new_failures
  @new_failures
end

#new_fixesFixnum

Output only. Number of new fixes compared to the previous execution. Corresponds to the JSON property newFixes

Returns:

  • (Fixnum)


3871
3872
3873
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3871

def new_fixes
  @new_fixes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3878
3879
3880
3881
3882
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3878

def update!(**args)
  @failures = args[:failures] if args.key?(:failures)
  @new_failures = args[:new_failures] if args.key?(:new_failures)
  @new_fixes = args[:new_fixes] if args.key?(:new_fixes)
end