Class: Google::Apis::WorkloadmanagerV1::TorsoValidation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

The schema of torso workload validation data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TorsoValidation

Returns a new instance of TorsoValidation.



3940
3941
3942
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3940

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_versionString

Required. agent_version lists the version of the agent that collected this data. Corresponds to the JSON property agentVersion

Returns:

  • (String)


3915
3916
3917
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3915

def agent_version
  @agent_version
end

#instance_nameString

Optional. instance_name lists the human readable name of the instance that the data comes from. Corresponds to the JSON property instanceName

Returns:

  • (String)


3921
3922
3923
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3921

def instance_name
  @instance_name
end

#project_idString

Required. project_id lists the human readable cloud project that the data comes from. Corresponds to the JSON property projectId

Returns:

  • (String)


3927
3928
3929
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3927

def project_id
  @project_id
end

#validation_detailsHash<String,String>

Required. validation_details contains the pairs of validation data: field name & field value. Corresponds to the JSON property validationDetails

Returns:

  • (Hash<String,String>)


3933
3934
3935
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3933

def validation_details
  @validation_details
end

#workload_typeString

Required. workload_type specifies the type of torso workload. Corresponds to the JSON property workloadType

Returns:

  • (String)


3938
3939
3940
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3938

def workload_type
  @workload_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3945
3946
3947
3948
3949
3950
3951
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3945

def update!(**args)
  @agent_version = args[:agent_version] if args.key?(:agent_version)
  @instance_name = args[:instance_name] if args.key?(:instance_name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @validation_details = args[:validation_details] if args.key?(:validation_details)
  @workload_type = args[:workload_type] if args.key?(:workload_type)
end