Class: Google::Apis::WorkloadmanagerV1::WorkloadManagerService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::WorkloadmanagerV1::WorkloadManagerService
- Defined in:
- lib/google/apis/workloadmanager_v1/service.rb
Overview
Workload Manager API
Workload Manager is a service that provides tooling for enterprise workloads to automate the deployment and validation of your workloads against best practices and recommendations.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://workloadmanager.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_deployment(parent, deployment_object = nil, deployment_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Creates a new Deployment in a given project and location.
-
#create_project_location_deployment_actuation(parent, actuation_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Creates a new actuation for an existing Deployment.
-
#create_project_location_evaluation(parent, evaluation_object = nil, evaluation_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Creates a new Evaluation in a given project and location.
-
#delete_project_location_deployment(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Deletes a single Deployment.
-
#delete_project_location_deployment_actuation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Deletes a single Actuation.
-
#delete_project_location_evaluation(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Deletes a single Evaluation.
-
#delete_project_location_evaluation_execution(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Deletes a single Execution.
-
#delete_project_location_insight(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Empty
Delete the data insights from workload manager data warehouse.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Location
Gets information about a location.
-
#get_project_location_deployment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Deployment
Gets details of a single Deployment.
-
#get_project_location_deployment_actuation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Actuation
Gets details of a single Actuation.
-
#get_project_location_discoveredprofile(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::WorkloadProfile
Gets details of a discovered workload profile.
-
#get_project_location_discoveredprofile_health(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::WorkloadProfileHealth
Get the health of a discovered workload profile.
-
#get_project_location_evaluation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Evaluation
Gets details of a single Evaluation.
-
#get_project_location_evaluation_execution(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Execution
Gets details of a single Execution.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ WorkloadManagerService
constructor
A new instance of WorkloadManagerService.
-
#list_project_location_deployment_actuations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListActuationsResponse
Lists Actuations in a given project, location and deployment.
-
#list_project_location_deployments(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListDeploymentsResponse
Lists Deployments in a given project and location.
-
#list_project_location_discoveredprofiles(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListDiscoveredProfilesResponse
List discovered workload profiles.
-
#list_project_location_evaluation_execution_results(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListExecutionResultsResponse
Lists the result of a single evaluation.
-
#list_project_location_evaluation_execution_scanned_resources(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, rule: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListScannedResourcesResponse
List all scanned resources for a single Execution.
-
#list_project_location_evaluation_executions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListExecutionsResponse
Lists Executions in a given project and location.
-
#list_project_location_evaluations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListEvaluationsResponse
Lists Evaluations in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_rules(parent, custom_rules_bucket: nil, evaluation_type: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListRulesResponse
Lists rules in a given project.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_evaluation(name, evaluation_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Updates the parameters of a single Evaluation.
-
#run_execution_evaluation(name, run_evaluation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Creates a new Execution in a given project and location.
-
#write_insight(location, write_insight_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::WriteInsightResponse
Write the data insights to workload manager data warehouse.
Constructor Details
#initialize ⇒ WorkloadManagerService
Returns a new instance of WorkloadManagerService.
49 50 51 52 53 54 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 49 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-workloadmanager_v1', client_version: Google::Apis::WorkloadmanagerV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
42 43 44 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 42 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
47 48 49 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 47 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 1114 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::WorkloadmanagerV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::WorkloadmanagerV1::Empty::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_deployment(parent, deployment_object = nil, deployment_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Creates a new Deployment in a given project and location.
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 177 def create_project_location_deployment(parent, deployment_object = nil, deployment_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/deployments', ) command.request_representation = Google::Apis::WorkloadmanagerV1::Deployment::Representation command.request_object = deployment_object command.response_representation = Google::Apis::WorkloadmanagerV1::Operation::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['deploymentId'] = deployment_id unless deployment_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_deployment_actuation(parent, actuation_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Creates a new actuation for an existing Deployment.
334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 334 def create_project_location_deployment_actuation(parent, actuation_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/actuations', ) command.request_representation = Google::Apis::WorkloadmanagerV1::Actuation::Representation command.request_object = actuation_object command.response_representation = Google::Apis::WorkloadmanagerV1::Operation::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_evaluation(parent, evaluation_object = nil, evaluation_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Creates a new Evaluation in a given project and location.
588 589 590 591 592 593 594 595 596 597 598 599 600 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 588 def create_project_location_evaluation(parent, evaluation_object = nil, evaluation_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/evaluations', ) command.request_representation = Google::Apis::WorkloadmanagerV1::Evaluation::Representation command.request_object = evaluation_object command.response_representation = Google::Apis::WorkloadmanagerV1::Operation::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['evaluationId'] = evaluation_id unless evaluation_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_deployment(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Deletes a single Deployment.
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 214 def delete_project_location_deployment(name, force: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::Operation::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_deployment_actuation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Deletes a single Actuation
368 369 370 371 372 373 374 375 376 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 368 def delete_project_location_deployment_actuation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::Operation::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_evaluation(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Deletes a single Evaluation.
635 636 637 638 639 640 641 642 643 644 645 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 635 def delete_project_location_evaluation(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::Operation::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_evaluation_execution(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Deletes a single Execution.
803 804 805 806 807 808 809 810 811 812 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 803 def delete_project_location_evaluation_execution(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::Operation::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_insight(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Empty
Delete the data insights from workload manager data warehouse.
1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 1041 def delete_project_location_insight(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::Empty::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Empty command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1149 1150 1151 1152 1153 1154 1155 1156 1157 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 1149 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::Empty::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Location
Gets information about a location.
76 77 78 79 80 81 82 83 84 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 76 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::Location::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_deployment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Deployment
Gets details of a single Deployment.
246 247 248 249 250 251 252 253 254 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 246 def get_project_location_deployment(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::Deployment::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Deployment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_deployment_actuation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Actuation
Gets details of a single Actuation.
398 399 400 401 402 403 404 405 406 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 398 def get_project_location_deployment_actuation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::Actuation::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Actuation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_discoveredprofile(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::WorkloadProfile
Gets details of a discovered workload profile.
473 474 475 476 477 478 479 480 481 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 473 def get_project_location_discoveredprofile(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::WorkloadProfile::Representation command.response_class = Google::Apis::WorkloadmanagerV1::WorkloadProfile command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_discoveredprofile_health(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::WorkloadProfileHealth
Get the health of a discovered workload profile.
543 544 545 546 547 548 549 550 551 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 543 def get_project_location_discoveredprofile_health(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::WorkloadProfileHealth::Representation command.response_class = Google::Apis::WorkloadmanagerV1::WorkloadProfileHealth command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_evaluation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Evaluation
Gets details of a single Evaluation.
667 668 669 670 671 672 673 674 675 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 667 def get_project_location_evaluation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::Evaluation::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Evaluation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_evaluation_execution(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Execution
Gets details of a single Execution.
834 835 836 837 838 839 840 841 842 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 834 def get_project_location_evaluation_execution(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::Execution::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Execution command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1180 1181 1182 1183 1184 1185 1186 1187 1188 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 1180 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkloadmanagerV1::Operation::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_deployment_actuations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListActuationsResponse
Lists Actuations in a given project, location and deployment.
439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 439 def list_project_location_deployment_actuations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/actuations', ) command.response_representation = Google::Apis::WorkloadmanagerV1::ListActuationsResponse::Representation command.response_class = Google::Apis::WorkloadmanagerV1::ListActuationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_deployments(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListDeploymentsResponse
Lists Deployments in a given project and location.
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 287 def list_project_location_deployments(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/deployments', ) command.response_representation = Google::Apis::WorkloadmanagerV1::ListDeploymentsResponse::Representation command.response_class = Google::Apis::WorkloadmanagerV1::ListDeploymentsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_discoveredprofiles(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListDiscoveredProfilesResponse
List discovered workload profiles
510 511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 510 def list_project_location_discoveredprofiles(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/discoveredprofiles', ) command.response_representation = Google::Apis::WorkloadmanagerV1::ListDiscoveredProfilesResponse::Representation command.response_class = Google::Apis::WorkloadmanagerV1::ListDiscoveredProfilesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_evaluation_execution_results(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListExecutionResultsResponse
Lists the result of a single evaluation.
950 951 952 953 954 955 956 957 958 959 960 961 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 950 def list_project_location_evaluation_execution_results(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/results', ) command.response_representation = Google::Apis::WorkloadmanagerV1::ListExecutionResultsResponse::Representation command.response_class = Google::Apis::WorkloadmanagerV1::ListExecutionResultsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_evaluation_execution_scanned_resources(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, rule: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListScannedResourcesResponse
List all scanned resources for a single Execution.
994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 994 def list_project_location_evaluation_execution_scanned_resources(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, rule: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/scannedResources', ) command.response_representation = Google::Apis::WorkloadmanagerV1::ListScannedResourcesResponse::Representation command.response_class = Google::Apis::WorkloadmanagerV1::ListScannedResourcesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['rule'] = rule unless rule.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_evaluation_executions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListExecutionsResponse
Lists Executions in a given project and location.
874 875 876 877 878 879 880 881 882 883 884 885 886 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 874 def list_project_location_evaluation_executions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/executions', ) command.response_representation = Google::Apis::WorkloadmanagerV1::ListExecutionsResponse::Representation command.response_class = Google::Apis::WorkloadmanagerV1::ListExecutionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_evaluations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListEvaluationsResponse
Lists Evaluations in a given project and location.
706 707 708 709 710 711 712 713 714 715 716 717 718 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 706 def list_project_location_evaluations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/evaluations', ) command.response_representation = Google::Apis::WorkloadmanagerV1::ListEvaluationsResponse::Representation command.response_class = Google::Apis::WorkloadmanagerV1::ListEvaluationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 1225 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::WorkloadmanagerV1::ListOperationsResponse::Representation command.response_class = Google::Apis::WorkloadmanagerV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_rules(parent, custom_rules_bucket: nil, evaluation_type: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListRulesResponse
Lists rules in a given project.
1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 1273 def list_project_location_rules(parent, custom_rules_bucket: nil, evaluation_type: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/rules', ) command.response_representation = Google::Apis::WorkloadmanagerV1::ListRulesResponse::Representation command.response_class = Google::Apis::WorkloadmanagerV1::ListRulesResponse command.params['parent'] = parent unless parent.nil? command.query['customRulesBucket'] = custom_rules_bucket unless custom_rules_bucket.nil? command.query['evaluationType'] = evaluation_type unless evaluation_type.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 128 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::WorkloadmanagerV1::ListLocationsResponse::Representation command.response_class = Google::Apis::WorkloadmanagerV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_evaluation(name, evaluation_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Updates the parameters of a single Evaluation.
758 759 760 761 762 763 764 765 766 767 768 769 770 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 758 def patch_project_location_evaluation(name, evaluation_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::WorkloadmanagerV1::Evaluation::Representation command.request_object = evaluation_object command.response_representation = Google::Apis::WorkloadmanagerV1::Operation::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#run_execution_evaluation(name, run_evaluation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::Operation
Creates a new Execution in a given project and location.
910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 910 def run_execution_evaluation(name, run_evaluation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}/executions:run', ) command.request_representation = Google::Apis::WorkloadmanagerV1::RunEvaluationRequest::Representation command.request_object = run_evaluation_request_object command.response_representation = Google::Apis::WorkloadmanagerV1::Operation::Representation command.response_class = Google::Apis::WorkloadmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#write_insight(location, write_insight_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkloadmanagerV1::WriteInsightResponse
Write the data insights to workload manager data warehouse.
1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/google/apis/workloadmanager_v1/service.rb', line 1074 def write_insight(location, write_insight_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+location}/insights:writeInsight', ) command.request_representation = Google::Apis::WorkloadmanagerV1::WriteInsightRequest::Representation command.request_object = write_insight_request_object command.response_representation = Google::Apis::WorkloadmanagerV1::WriteInsightResponse::Representation command.response_class = Google::Apis::WorkloadmanagerV1::WriteInsightResponse command.params['location'] = location unless location.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |