Class: Google::Apis::WorkloadmanagerV1::WorkloadProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Workload resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadProfile

Returns a new instance of WorkloadProfile.



4065
4066
4067
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4065

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Optional. such as name, description, version. More example can be found in deployment Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4042
4043
4044
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4042

def labels
  @labels
end

#nameString

Identifier. name of resource names have the form 'projects/project_id/ locations/location/workloadProfiles/workload_id' Corresponds to the JSON property name

Returns:

  • (String)


4048
4049
4050
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4048

def name
  @name
end

#refreshed_timeString

Required. time when the workload data was refreshed Corresponds to the JSON property refreshedTime

Returns:

  • (String)


4053
4054
4055
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4053

def refreshed_time
  @refreshed_time
end

#sap_workloadGoogle::Apis::WorkloadmanagerV1::SapWorkload

The body of sap workload Corresponds to the JSON property sapWorkload



4058
4059
4060
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4058

def sap_workload
  @sap_workload
end

#workload_typeString

Required. The type of the workload Corresponds to the JSON property workloadType

Returns:

  • (String)


4063
4064
4065
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4063

def workload_type
  @workload_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4070
4071
4072
4073
4074
4075
4076
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4070

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @refreshed_time = args[:refreshed_time] if args.key?(:refreshed_time)
  @sap_workload = args[:sap_workload] if args.key?(:sap_workload)
  @workload_type = args[:workload_type] if args.key?(:workload_type)
end