Class: Google::Apis::WorkloadmanagerV1::Actuation
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::Actuation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
The Actuation object represents the bootstrap state and output results of deployed infrastructure and software.
Instance Attribute Summary collapse
-
#actuation_output ⇒ Google::Apis::WorkloadmanagerV1::ActuationOutput
Message for output of Actuation Corresponds to the JSON property
actuationOutput. -
#deployment_output ⇒ Array<Google::Apis::WorkloadmanagerV1::DeploymentOutput>
Output only.
-
#end_time ⇒ String
Output only.
-
#name ⇒ String
The name of actuation resource.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Actuation
constructor
A new instance of Actuation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Actuation
Returns a new instance of Actuation.
104 105 106 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actuation_output ⇒ Google::Apis::WorkloadmanagerV1::ActuationOutput
Message for output of Actuation
Corresponds to the JSON property actuationOutput
76 77 78 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 76 def actuation_output @actuation_output end |
#deployment_output ⇒ Array<Google::Apis::WorkloadmanagerV1::DeploymentOutput>
Output only. [Output only] Deployment output
Corresponds to the JSON property deploymentOutput
81 82 83 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 81 def deployment_output @deployment_output end |
#end_time ⇒ String
Output only. [Output only] End time stamp
Corresponds to the JSON property endTime
86 87 88 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 86 def end_time @end_time end |
#name ⇒ String
The name of actuation resource. The format is projects/project/locations/
location/deployments/deployment/actuations/actuation
Corresponds to the JSON property name
92 93 94 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 92 def name @name end |
#start_time ⇒ String
Output only. [Output only] Start time stamp
Corresponds to the JSON property startTime
97 98 99 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 97 def start_time @start_time end |
#state ⇒ String
Output only. [Output only] Actuation state
Corresponds to the JSON property state
102 103 104 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 102 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
109 110 111 112 113 114 115 116 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 109 def update!(**args) @actuation_output = args[:actuation_output] if args.key?(:actuation_output) @deployment_output = args[:deployment_output] if args.key?(:deployment_output) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |