Class: Google::Apis::WorkloadmanagerV1::ActuationOutput
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::ActuationOutput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
Message for output of Actuation
Instance Attribute Summary collapse
-
#actuate_logs ⇒ String
A link to gcs file that store build logs Corresponds to the JSON property
actuateLogs. -
#ansible_error ⇒ String
Output only.
-
#ansible_failed_task ⇒ Array<String>
Output only.
-
#blueprint_id ⇒ String
reference to Blueprint Controller deployment and revision resource Corresponds to the JSON property
blueprintId. -
#cloudbuild_id ⇒ String
Cloud Build instance UUID associated with this revision, without any suffix or prefix Corresponds to the JSON property
cloudbuildId. -
#error_code ⇒ String
Output only.
-
#error_logs ⇒ String
A link to actuation cloud build log.
-
#has_user_facing_error_msg ⇒ Boolean
(also: #has_user_facing_error_msg?)
Output only.
-
#terraform_error ⇒ String
Output only.
-
#terraform_template ⇒ String
reference to terraform template used Corresponds to the JSON property
terraformTemplate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ActuationOutput
constructor
A new instance of ActuationOutput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ActuationOutput
Returns a new instance of ActuationOutput.
177 178 179 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 177 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actuate_logs ⇒ String
A link to gcs file that store build logs
Corresponds to the JSON property actuateLogs
126 127 128 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 126 def actuate_logs @actuate_logs end |
#ansible_error ⇒ String
Output only. error message return from ansible.
Corresponds to the JSON property ansibleError
131 132 133 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 131 def ansible_error @ansible_error end |
#ansible_failed_task ⇒ Array<String>
Output only. failed task name return from ansible.
Corresponds to the JSON property ansibleFailedTask
136 137 138 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 136 def ansible_failed_task @ansible_failed_task end |
#blueprint_id ⇒ String
reference to Blueprint Controller deployment and revision resource
Corresponds to the JSON property blueprintId
141 142 143 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 141 def blueprint_id @blueprint_id end |
#cloudbuild_id ⇒ String
Cloud Build instance UUID associated with this revision, without any suffix or
prefix
Corresponds to the JSON property cloudbuildId
147 148 149 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 147 def cloudbuild_id @cloudbuild_id end |
#error_code ⇒ String
Output only. Code describing any errors that may have occurred. If not
specified, there is no error in actuation.
Corresponds to the JSON property errorCode
153 154 155 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 153 def error_code @error_code end |
#error_logs ⇒ String
A link to actuation cloud build log.
Corresponds to the JSON property errorLogs
158 159 160 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 158 def error_logs @error_logs end |
#has_user_facing_error_msg ⇒ Boolean Also known as: has_user_facing_error_msg?
Output only. whether the error message is user facing. If true, the error
message will be shown in the UI.
Corresponds to the JSON property hasUserFacingErrorMsg
164 165 166 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 164 def has_user_facing_error_msg @has_user_facing_error_msg end |
#terraform_error ⇒ String
Output only. error message return from terraform.
Corresponds to the JSON property terraformError
170 171 172 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 170 def terraform_error @terraform_error end |
#terraform_template ⇒ String
reference to terraform template used
Corresponds to the JSON property terraformTemplate
175 176 177 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 175 def terraform_template @terraform_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 182 def update!(**args) @actuate_logs = args[:actuate_logs] if args.key?(:actuate_logs) @ansible_error = args[:ansible_error] if args.key?(:ansible_error) @ansible_failed_task = args[:ansible_failed_task] if args.key?(:ansible_failed_task) @blueprint_id = args[:blueprint_id] if args.key?(:blueprint_id) @cloudbuild_id = args[:cloudbuild_id] if args.key?(:cloudbuild_id) @error_code = args[:error_code] if args.key?(:error_code) @error_logs = args[:error_logs] if args.key?(:error_logs) @has_user_facing_error_msg = args[:has_user_facing_error_msg] if args.key?(:has_user_facing_error_msg) @terraform_error = args[:terraform_error] if args.key?(:terraform_error) @terraform_template = args[:terraform_template] if args.key?(:terraform_template) end |