Class: Google::Apis::WorkloadmanagerV1::AgentStates
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::AgentStates
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
Agent status.
Instance Attribute Summary collapse
-
#available_version ⇒ String
Optional.
-
#hana_monitoring ⇒ Google::Apis::WorkloadmanagerV1::ServiceStates
The state of the service.
-
#installed_version ⇒ String
Optional.
-
#is_fully_enabled ⇒ Boolean
(also: #is_fully_enabled?)
Optional.
-
#process_metrics ⇒ Google::Apis::WorkloadmanagerV1::ServiceStates
The state of the service.
-
#system_discovery ⇒ Google::Apis::WorkloadmanagerV1::ServiceStates
The state of the service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AgentStates
constructor
A new instance of AgentStates.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AgentStates
Returns a new instance of AgentStates.
258 259 260 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 258 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_version ⇒ String
Optional. The available version of the agent in artifact registry.
Corresponds to the JSON property availableVersion
229 230 231 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 229 def available_version @available_version end |
#hana_monitoring ⇒ Google::Apis::WorkloadmanagerV1::ServiceStates
The state of the service.
Corresponds to the JSON property hanaMonitoring
234 235 236 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 234 def hana_monitoring @hana_monitoring end |
#installed_version ⇒ String
Optional. The installed version of the agent on the host.
Corresponds to the JSON property installedVersion
239 240 241 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 239 def installed_version @installed_version end |
#is_fully_enabled ⇒ Boolean Also known as: is_fully_enabled?
Optional. Whether the agent is fully enabled. If false, the agent is has some
issues.
Corresponds to the JSON property isFullyEnabled
245 246 247 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 245 def is_fully_enabled @is_fully_enabled end |
#process_metrics ⇒ Google::Apis::WorkloadmanagerV1::ServiceStates
The state of the service.
Corresponds to the JSON property processMetrics
251 252 253 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 251 def process_metrics @process_metrics end |
#system_discovery ⇒ Google::Apis::WorkloadmanagerV1::ServiceStates
The state of the service.
Corresponds to the JSON property systemDiscovery
256 257 258 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 256 def system_discovery @system_discovery end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
263 264 265 266 267 268 269 270 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 263 def update!(**args) @available_version = args[:available_version] if args.key?(:available_version) @hana_monitoring = args[:hana_monitoring] if args.key?(:hana_monitoring) @installed_version = args[:installed_version] if args.key?(:installed_version) @is_fully_enabled = args[:is_fully_enabled] if args.key?(:is_fully_enabled) @process_metrics = args[:process_metrics] if args.key?(:process_metrics) @system_discovery = args[:system_discovery] if args.key?(:system_discovery) end |