Class: Google::Apis::WorkloadmanagerV1::AgentStatus
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::AgentStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
The schema of agent status data.
Instance Attribute Summary collapse
-
#agent_name ⇒ String
Output only.
-
#available_version ⇒ String
Output only.
-
#cloud_api_access_full_scopes_granted ⇒ String
Output only.
-
#configuration_error_message ⇒ String
Output only.
-
#configuration_file_path ⇒ String
Output only.
-
#configuration_valid ⇒ String
Output only.
-
#installed_version ⇒ String
Output only.
-
#instance_uri ⇒ String
Output only.
-
#kernel_version ⇒ Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesKernelVersion
KernelVersion encapsulates the kernel version data for the system.
-
#references ⇒ Array<Google::Apis::WorkloadmanagerV1::AgentStatusReference>
Output only.
-
#services ⇒ Array<Google::Apis::WorkloadmanagerV1::AgentStatusServiceStatus>
Output only.
-
#systemd_service_enabled ⇒ String
Output only.
-
#systemd_service_running ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AgentStatus
constructor
A new instance of AgentStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AgentStatus
Returns a new instance of AgentStatus.
342 343 344 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 342 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_name ⇒ String
Output only. The name of the agent.
Corresponds to the JSON property agentName
280 281 282 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 280 def agent_name @agent_name end |
#available_version ⇒ String
Output only. The available version of the agent in artifact registry.
Corresponds to the JSON property availableVersion
285 286 287 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 285 def available_version @available_version end |
#cloud_api_access_full_scopes_granted ⇒ String
Output only. Whether the agent has full access to Cloud APIs.
Corresponds to the JSON property cloudApiAccessFullScopesGranted
290 291 292 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 290 def cloud_api_access_full_scopes_granted @cloud_api_access_full_scopes_granted end |
#configuration_error_message ⇒ String
Output only. The error message for the agent configuration if invalid.
Corresponds to the JSON property configurationErrorMessage
295 296 297 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 295 def @configuration_error_message end |
#configuration_file_path ⇒ String
Output only. The path to the agent configuration file.
Corresponds to the JSON property configurationFilePath
300 301 302 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 300 def configuration_file_path @configuration_file_path end |
#configuration_valid ⇒ String
Output only. Whether the agent configuration is valid.
Corresponds to the JSON property configurationValid
305 306 307 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 305 def configuration_valid @configuration_valid end |
#installed_version ⇒ String
Output only. The installed version of the agent on the host.
Corresponds to the JSON property installedVersion
310 311 312 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 310 def installed_version @installed_version end |
#instance_uri ⇒ String
Output only. The URI of the instance. Format: projects//zones//instances/
Corresponds to the JSON property instanceUri
315 316 317 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 315 def instance_uri @instance_uri end |
#kernel_version ⇒ Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesKernelVersion
KernelVersion encapsulates the kernel version data for the system.
Corresponds to the JSON property kernelVersion
320 321 322 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 320 def kernel_version @kernel_version end |
#references ⇒ Array<Google::Apis::WorkloadmanagerV1::AgentStatusReference>
Output only. Optional references to public documentation.
Corresponds to the JSON property references
325 326 327 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 325 def references @references end |
#services ⇒ Array<Google::Apis::WorkloadmanagerV1::AgentStatusServiceStatus>
Output only. The services (process metrics, host metrics, etc.).
Corresponds to the JSON property services
330 331 332 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 330 def services @services end |
#systemd_service_enabled ⇒ String
Output only. Whether the agent service is enabled in systemd.
Corresponds to the JSON property systemdServiceEnabled
335 336 337 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 335 def systemd_service_enabled @systemd_service_enabled end |
#systemd_service_running ⇒ String
Output only. Whether the agent service is running in systemd.
Corresponds to the JSON property systemdServiceRunning
340 341 342 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 340 def systemd_service_running @systemd_service_running end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 347 def update!(**args) @agent_name = args[:agent_name] if args.key?(:agent_name) @available_version = args[:available_version] if args.key?(:available_version) @cloud_api_access_full_scopes_granted = args[:cloud_api_access_full_scopes_granted] if args.key?(:cloud_api_access_full_scopes_granted) @configuration_error_message = args[:configuration_error_message] if args.key?(:configuration_error_message) @configuration_file_path = args[:configuration_file_path] if args.key?(:configuration_file_path) @configuration_valid = args[:configuration_valid] if args.key?(:configuration_valid) @installed_version = args[:installed_version] if args.key?(:installed_version) @instance_uri = args[:instance_uri] if args.key?(:instance_uri) @kernel_version = args[:kernel_version] if args.key?(:kernel_version) @references = args[:references] if args.key?(:references) @services = args[:services] if args.key?(:services) @systemd_service_enabled = args[:systemd_service_enabled] if args.key?(:systemd_service_enabled) @systemd_service_running = args[:systemd_service_running] if args.key?(:systemd_service_running) end |