Class: Google::Apis::WorkloadmanagerV1::Deployment
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::Deployment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
The Deployment object represents user intent for deploying a specific type of workload.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the Deployment Corresponds to the JSON property
description. -
#name ⇒ String
The name of deployment resource.
-
#sap_system_s4_config ⇒ Google::Apis::WorkloadmanagerV1::SapSystemS4Config
Message for sap system workload Corresponds to the JSON property
sapSystemS4Config. -
#service_account ⇒ String
User-specified Service Account (SA) credentials to be used for cloud build Format:
projects/projectID/serviceAccounts/serviceAccount`The default Cloud Build SA will be used initially if this field is not set during deployment creation Corresponds to the JSON propertyserviceAccount`. -
#sql_server_workload ⇒ Google::Apis::WorkloadmanagerV1::SqlServerWorkload
Message for MS SQL workload Corresponds to the JSON property
sqlServerWorkload. -
#state ⇒ String
Output only.
-
#terraform_variables ⇒ Hash<String,Google::Apis::WorkloadmanagerV1::TerraformVariable>
Optional.
-
#update_time ⇒ String
Output only.
-
#worker_pool ⇒ String
Optional.
-
#workload_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Deployment
constructor
A new instance of Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Deployment
Returns a new instance of Deployment.
1024 1025 1026 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. [Output only] Create time stamp
Corresponds to the JSON property createTime
961 962 963 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 961 def create_time @create_time end |
#description ⇒ String
Description of the Deployment
Corresponds to the JSON property description
966 967 968 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 966 def description @description end |
#name ⇒ String
The name of deployment resource. The format will be 'projects/project_id/
locations/location_id/deployments/deployment_id'
Corresponds to the JSON property name
972 973 974 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 972 def name @name end |
#sap_system_s4_config ⇒ Google::Apis::WorkloadmanagerV1::SapSystemS4Config
Message for sap system workload
Corresponds to the JSON property sapSystemS4Config
977 978 979 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 977 def sap_system_s4_config @sap_system_s4_config end |
#service_account ⇒ String
User-specified Service Account (SA) credentials to be used for cloud build
Format: projects/projectID/serviceAccounts/serviceAccount`The default
Cloud Build SA will be used initially if this field is not set during
deployment creation
Corresponds to the JSON propertyserviceAccount`
985 986 987 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 985 def service_account @service_account end |
#sql_server_workload ⇒ Google::Apis::WorkloadmanagerV1::SqlServerWorkload
Message for MS SQL workload
Corresponds to the JSON property sqlServerWorkload
990 991 992 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 990 def sql_server_workload @sql_server_workload end |
#state ⇒ String
Output only. Current state of the deployment.
Corresponds to the JSON property state
995 996 997 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 995 def state @state end |
#terraform_variables ⇒ Hash<String,Google::Apis::WorkloadmanagerV1::TerraformVariable>
Optional. terraform_variables represents all the Terraform variables for the
deployment workload. The key is the name of the Terraform variable, and the
value is the TerraformVariable. For example: "project_id": "input_value":
"string_value": "my-project-id" , "zone": "input_value": "string_value"
: "us-central1-a"
Corresponds to the JSON property terraformVariables
1004 1005 1006 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1004 def terraform_variables @terraform_variables end |
#update_time ⇒ String
Output only. [Output only] Update time stamp
Corresponds to the JSON property updateTime
1009 1010 1011 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1009 def update_time @update_time end |
#worker_pool ⇒ String
Optional. The user-specified Cloud Build worker pool resource in which the
Cloud Build job will execute. Format: projects/project/locations/location/
workerPools/workerPoolId`. If this field is unspecified, the default Cloud
Build worker pool will be used.
Corresponds to the JSON propertyworkerPool`
1017 1018 1019 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1017 def worker_pool @worker_pool end |
#workload_type ⇒ String
Optional. Workload type of the deployment
Corresponds to the JSON property workloadType
1022 1023 1024 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1022 def workload_type @workload_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1029 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @sap_system_s4_config = args[:sap_system_s4_config] if args.key?(:sap_system_s4_config) @service_account = args[:service_account] if args.key?(:service_account) @sql_server_workload = args[:sql_server_workload] if args.key?(:sql_server_workload) @state = args[:state] if args.key?(:state) @terraform_variables = args[:terraform_variables] if args.key?(:terraform_variables) @update_time = args[:update_time] if args.key?(:update_time) @worker_pool = args[:worker_pool] if args.key?(:worker_pool) @workload_type = args[:workload_type] if args.key?(:workload_type) end |