Class: Google::Apis::WorkloadmanagerV1::Evaluation
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::Evaluation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
Represents a Workload Manager Evaluation configuration. An Evaluation defines a set of rules to be validated against a scope of Cloud resources.
Instance Attribute Summary collapse
-
#big_query_destination ⇒ Google::Apis::WorkloadmanagerV1::BigQueryDestination
BigQuery destination for evaluation results.
-
#create_time ⇒ String
Output only.
-
#custom_rules_bucket ⇒ String
The Cloud Storage bucket name for custom rules.
-
#description ⇒ String
Description of the Evaluation.
-
#evaluation_type ⇒ String
Evaluation type.
-
#kms_key ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Labels as key value pairs.
-
#name ⇒ String
Name of resource that has the form
projects/project_id/locations/location_id/evaluations/evaluation_id``. -
#resource_filter ⇒ Google::Apis::WorkloadmanagerV1::ResourceFilter
Resource filter for an evaluation defining the scope of resources to be evaluated.
-
#resource_status ⇒ Google::Apis::WorkloadmanagerV1::ResourceStatus
The lifecycle status of an Evaluation resource.
-
#rule_names ⇒ Array<String>
The names of the rules used for this evaluation.
-
#schedule ⇒ String
Crontab format schedule for scheduled evaluation, currently only supports the following fixed schedules: *
0 */1 * * *# Hourly *0 */6 * * *# Every 6 hours *0 */12 * * *# Every 12 hours *0 0 */1 * *# Daily *0 0 */7 * *# Weekly *0 0 */14 * *# Every 14 days *0 0 1 */1 *# Monthly Corresponds to the JSON propertyschedule. -
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Evaluation
constructor
A new instance of Evaluation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Evaluation
Returns a new instance of Evaluation.
1162 1163 1164 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_destination ⇒ Google::Apis::WorkloadmanagerV1::BigQueryDestination
BigQuery destination for evaluation results.
Corresponds to the JSON property bigQueryDestination
1093 1094 1095 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1093 def big_query_destination @big_query_destination end |
#create_time ⇒ String
Output only. [Output only] Create time stamp.
Corresponds to the JSON property createTime
1098 1099 1100 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1098 def create_time @create_time end |
#custom_rules_bucket ⇒ String
The Cloud Storage bucket name for custom rules.
Corresponds to the JSON property customRulesBucket
1103 1104 1105 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1103 def custom_rules_bucket @custom_rules_bucket end |
#description ⇒ String
Description of the Evaluation.
Corresponds to the JSON property description
1108 1109 1110 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1108 def description @description end |
#evaluation_type ⇒ String
Evaluation type.
Corresponds to the JSON property evaluationType
1113 1114 1115 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1113 def evaluation_type @evaluation_type end |
#kms_key ⇒ String
Optional. Immutable. Customer-managed encryption key name, in the format
projects//locations//keyRings//cryptoKeys/. The key will be used for CMEK
encryption of the evaluation resource.
Corresponds to the JSON property kmsKey
1120 1121 1122 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1120 def kms_key @kms_key end |
#labels ⇒ Hash<String,String>
Labels as key value pairs.
Corresponds to the JSON property labels
1125 1126 1127 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1125 def labels @labels end |
#name ⇒ String
Name of resource that has the form projects/project_id/locations/
location_id/evaluations/evaluation_id`.
Corresponds to the JSON propertyname`
1131 1132 1133 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1131 def name @name end |
#resource_filter ⇒ Google::Apis::WorkloadmanagerV1::ResourceFilter
Resource filter for an evaluation defining the scope of resources to be
evaluated.
Corresponds to the JSON property resourceFilter
1137 1138 1139 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1137 def resource_filter @resource_filter end |
#resource_status ⇒ Google::Apis::WorkloadmanagerV1::ResourceStatus
The lifecycle status of an Evaluation resource.
Corresponds to the JSON property resourceStatus
1142 1143 1144 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1142 def resource_status @resource_status end |
#rule_names ⇒ Array<String>
The names of the rules used for this evaluation.
Corresponds to the JSON property ruleNames
1147 1148 1149 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1147 def rule_names @rule_names end |
#schedule ⇒ String
Crontab format schedule for scheduled evaluation, currently only supports the
following fixed schedules: * 0 */1 * * * # Hourly * 0 */6 * * * # Every 6
hours * 0 */12 * * * # Every 12 hours * 0 0 */1 * * # Daily * 0 0 */7 * *
Weekly * 0 0 */14 * * # Every 14 days * 0 0 1 */1 * # Monthly
Corresponds to the JSON property schedule
1155 1156 1157 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1155 def schedule @schedule end |
#update_time ⇒ String
Output only. [Output only] Update time stamp.
Corresponds to the JSON property updateTime
1160 1161 1162 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1160 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1167 def update!(**args) @big_query_destination = args[:big_query_destination] if args.key?(:big_query_destination) @create_time = args[:create_time] if args.key?(:create_time) @custom_rules_bucket = args[:custom_rules_bucket] if args.key?(:custom_rules_bucket) @description = args[:description] if args.key?(:description) @evaluation_type = args[:evaluation_type] if args.key?(:evaluation_type) @kms_key = args[:kms_key] if args.key?(:kms_key) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @resource_filter = args[:resource_filter] if args.key?(:resource_filter) @resource_status = args[:resource_status] if args.key?(:resource_status) @rule_names = args[:rule_names] if args.key?(:rule_names) @schedule = args[:schedule] if args.key?(:schedule) @update_time = args[:update_time] if args.key?(:update_time) end |