Class: Google::Apis::WorkloadmanagerV1::Execution
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::Execution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
Execution that represents a single run of an Evaluation.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Output only.
-
#engine ⇒ String
Optional.
-
#evaluation_id ⇒ String
Output only.
-
#external_data_sources ⇒ Array<Google::Apis::WorkloadmanagerV1::ExternalDataSources>
Optional.
-
#inventory_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Labels as key value pairs.
-
#name ⇒ String
The name of execution resource.
-
#notices ⇒ Array<Google::Apis::WorkloadmanagerV1::Notice>
Output only.
-
#result_summary ⇒ Google::Apis::WorkloadmanagerV1::Summary
Execution summary.
-
#rule_results ⇒ Array<Google::Apis::WorkloadmanagerV1::RuleExecutionResult>
Output only.
-
#run_type ⇒ String
Type which represents whether the execution executed directly by user or scheduled according to the
Evaluation.schedulefield. -
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Execution
constructor
A new instance of Execution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Execution
Returns a new instance of Execution.
1255 1256 1257 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1255 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Output only. [Output only] End time stamp.
Corresponds to the JSON property endTime
1191 1192 1193 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1191 def end_time @end_time end |
#engine ⇒ String
Optional. Engine.
Corresponds to the JSON property engine
1196 1197 1198 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1196 def engine @engine end |
#evaluation_id ⇒ String
Output only. [Output only] Evaluation ID.
Corresponds to the JSON property evaluationId
1201 1202 1203 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1201 def evaluation_id @evaluation_id end |
#external_data_sources ⇒ Array<Google::Apis::WorkloadmanagerV1::ExternalDataSources>
Optional. External data sources.
Corresponds to the JSON property externalDataSources
1206 1207 1208 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1206 def external_data_sources @external_data_sources end |
#inventory_time ⇒ String
Output only. [Output only] Inventory time stamp.
Corresponds to the JSON property inventoryTime
1211 1212 1213 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1211 def inventory_time @inventory_time end |
#labels ⇒ Hash<String,String>
Labels as key value pairs.
Corresponds to the JSON property labels
1216 1217 1218 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1216 def labels @labels end |
#name ⇒ String
The name of execution resource. The format is projects/project/locations/
location/evaluations/evaluation/executions/execution.
Corresponds to the JSON property name
1222 1223 1224 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1222 def name @name end |
#notices ⇒ Array<Google::Apis::WorkloadmanagerV1::Notice>
Output only. Additional information generated by the execution.
Corresponds to the JSON property notices
1227 1228 1229 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1227 def notices @notices end |
#result_summary ⇒ Google::Apis::WorkloadmanagerV1::Summary
Execution summary.
Corresponds to the JSON property resultSummary
1232 1233 1234 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1232 def result_summary @result_summary end |
#rule_results ⇒ Array<Google::Apis::WorkloadmanagerV1::RuleExecutionResult>
Output only. Execution result summary per rule.
Corresponds to the JSON property ruleResults
1237 1238 1239 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1237 def rule_results @rule_results end |
#run_type ⇒ String
Type which represents whether the execution executed directly by user or
scheduled according to the Evaluation.schedule field.
Corresponds to the JSON property runType
1243 1244 1245 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1243 def run_type @run_type end |
#start_time ⇒ String
Output only. [Output only] Start time stamp.
Corresponds to the JSON property startTime
1248 1249 1250 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1248 def start_time @start_time end |
#state ⇒ String
Output only. [Output only] State.
Corresponds to the JSON property state
1253 1254 1255 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1253 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1260 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @engine = args[:engine] if args.key?(:engine) @evaluation_id = args[:evaluation_id] if args.key?(:evaluation_id) @external_data_sources = args[:external_data_sources] if args.key?(:external_data_sources) @inventory_time = args[:inventory_time] if args.key?(:inventory_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @notices = args[:notices] if args.key?(:notices) @result_summary = args[:result_summary] if args.key?(:result_summary) @rule_results = args[:rule_results] if args.key?(:rule_results) @run_type = args[:run_type] if args.key?(:run_type) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |