Class: Google::Apis::WorkloadmanagerV1::LocationDetails
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::LocationDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
Message for sap instant details
Instance Attribute Summary collapse
-
#create_comms_firewall ⇒ Boolean
(also: #create_comms_firewall?)
Optional.
-
#custom_tags ⇒ Array<String>
Optional.
-
#deployment_dns_enabled ⇒ Boolean
(also: #deployment_dns_enabled?)
Optional.
-
#dns_zone ⇒ String
Optional.
-
#dns_zone_name_suffix ⇒ String
Optional.
-
#internet_access ⇒ String
Corresponds to the JSON property
internetAccess. -
#network_project ⇒ String
Optional.
-
#region_name ⇒ String
Required.
-
#subnet_name ⇒ String
Required.
-
#vpc_name ⇒ String
Required.
-
#zone1_name ⇒ String
Required.
-
#zone2_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocationDetails
constructor
A new instance of LocationDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocationDetails
Returns a new instance of LocationDetails.
1983 1984 1985 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1983 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_comms_firewall ⇒ Boolean Also known as: create_comms_firewall?
Optional. create firewall, if true, create firewall for the deployment. This
field provides an option to not always create firewall for the deployment.
Corresponds to the JSON property createCommsFirewall
1923 1924 1925 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1923 def create_comms_firewall @create_comms_firewall end |
#custom_tags ⇒ Array<String>
Optional. network tags
Corresponds to the JSON property customTags
1929 1930 1931 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1929 def @custom_tags end |
#deployment_dns_enabled ⇒ Boolean Also known as: deployment_dns_enabled?
Optional. when user skip DNS configuration from UI, deployment_dns_enabled=
false otherwise deployment_dns_enabled=true
Corresponds to the JSON property deploymentDnsEnabled
1935 1936 1937 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1935 def deployment_dns_enabled @deployment_dns_enabled end |
#dns_zone ⇒ String
Optional. dns zone name
Corresponds to the JSON property dnsZone
1941 1942 1943 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1941 def dns_zone @dns_zone end |
#dns_zone_name_suffix ⇒ String
Optional. dns_zone_name_suffix
Corresponds to the JSON property dnsZoneNameSuffix
1946 1947 1948 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1946 def dns_zone_name_suffix @dns_zone_name_suffix end |
#internet_access ⇒ String
Corresponds to the JSON property internetAccess
1951 1952 1953 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1951 def internet_access @internet_access end |
#network_project ⇒ String
Optional. network project
Corresponds to the JSON property networkProject
1956 1957 1958 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1956 def network_project @network_project end |
#region_name ⇒ String
Required. region_name
Corresponds to the JSON property regionName
1961 1962 1963 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1961 def region_name @region_name end |
#subnet_name ⇒ String
Required. subnet_name
Corresponds to the JSON property subnetName
1966 1967 1968 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1966 def subnet_name @subnet_name end |
#vpc_name ⇒ String
Required. vpc_name
Corresponds to the JSON property vpcName
1971 1972 1973 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1971 def vpc_name @vpc_name end |
#zone1_name ⇒ String
Required. zone1_name
Corresponds to the JSON property zone1Name
1976 1977 1978 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1976 def zone1_name @zone1_name end |
#zone2_name ⇒ String
Optional. zone2_name
Corresponds to the JSON property zone2Name
1981 1982 1983 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1981 def zone2_name @zone2_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 1988 def update!(**args) @create_comms_firewall = args[:create_comms_firewall] if args.key?(:create_comms_firewall) @custom_tags = args[:custom_tags] if args.key?(:custom_tags) @deployment_dns_enabled = args[:deployment_dns_enabled] if args.key?(:deployment_dns_enabled) @dns_zone = args[:dns_zone] if args.key?(:dns_zone) @dns_zone_name_suffix = args[:dns_zone_name_suffix] if args.key?(:dns_zone_name_suffix) @internet_access = args[:internet_access] if args.key?(:internet_access) @network_project = args[:network_project] if args.key?(:network_project) @region_name = args[:region_name] if args.key?(:region_name) @subnet_name = args[:subnet_name] if args.key?(:subnet_name) @vpc_name = args[:vpc_name] if args.key?(:vpc_name) @zone1_name = args[:zone1_name] if args.key?(:zone1_name) @zone2_name = args[:zone2_name] if args.key?(:zone2_name) end |