Class: Google::Apis::WorkloadmanagerV1::RunEvaluationRequest
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::RunEvaluationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
Request message for the RunEvaluation RPC.
Instance Attribute Summary collapse
-
#execution ⇒ Google::Apis::WorkloadmanagerV1::Execution
Execution that represents a single run of an Evaluation.
-
#execution_id ⇒ String
Required.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RunEvaluationRequest
constructor
A new instance of RunEvaluationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RunEvaluationRequest
Returns a new instance of RunEvaluationRequest.
2527 2528 2529 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2527 def initialize(**args) update!(**args) end |
Instance Attribute Details
#execution ⇒ Google::Apis::WorkloadmanagerV1::Execution
Execution that represents a single run of an Evaluation.
Corresponds to the JSON property execution
2506 2507 2508 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2506 def execution @execution end |
#execution_id ⇒ String
Required. ID of the execution which will be created.
Corresponds to the JSON property executionId
2511 2512 2513 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2511 def execution_id @execution_id end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes since the first request. For example, consider a
situation where you make an initial request and the request times out. If you
make the request again with the same request ID, the server can check if
original operation with the same request ID was received, and if so, will
ignore the second request. This prevents clients from accidentally creating
duplicate commitments. The request ID must be a valid UUID with the exception
that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
2525 2526 2527 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2525 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2532 2533 2534 2535 2536 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2532 def update!(**args) @execution = args[:execution] if args.key?(:execution) @execution_id = args[:execution_id] if args.key?(:execution_id) @request_id = args[:request_id] if args.key?(:request_id) end |