Class: Google::Apis::WorkloadmanagerV1::SapComponent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

The component of sap workload

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SapComponent

Returns a new instance of SapComponent.



2567
2568
2569
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_propertiesGoogle::Apis::WorkloadmanagerV1::DatabaseProperties

Database Properties. Corresponds to the JSON property databaseProperties



2544
2545
2546
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2544

def database_properties
  @database_properties
end

#ha_hostsArray<String>

List of host URIs that are part of the HA configuration if present. An empty list indicates the component is not configured for HA. Corresponds to the JSON property haHosts

Returns:

  • (Array<String>)


2550
2551
2552
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2550

def ha_hosts
  @ha_hosts
end

#resourcesArray<Google::Apis::WorkloadmanagerV1::CloudResource>

Output only. resources in the component Corresponds to the JSON property resources



2555
2556
2557
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2555

def resources
  @resources
end

#sidString

Output only. sid is the sap component identificator Corresponds to the JSON property sid

Returns:

  • (String)


2560
2561
2562
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2560

def sid
  @sid
end

#topology_typeString

The detected topology of the component. Corresponds to the JSON property topologyType

Returns:

  • (String)


2565
2566
2567
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2565

def topology_type
  @topology_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2572
2573
2574
2575
2576
2577
2578
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2572

def update!(**args)
  @database_properties = args[:database_properties] if args.key?(:database_properties)
  @ha_hosts = args[:ha_hosts] if args.key?(:ha_hosts)
  @resources = args[:resources] if args.key?(:resources)
  @sid = args[:sid] if args.key?(:sid)
  @topology_type = args[:topology_type] if args.key?(:topology_type)
end