Class: Google::Apis::WorkloadmanagerV1::SapDiscoveryComponent
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::SapDiscoveryComponent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
Message describing the system component.
Instance Attribute Summary collapse
-
#application_properties ⇒ Google::Apis::WorkloadmanagerV1::SapDiscoveryComponentApplicationProperties
A set of properties describing an SAP Application layer.
-
#database_properties ⇒ Google::Apis::WorkloadmanagerV1::SapDiscoveryComponentDatabaseProperties
A set of properties describing an SAP Database layer.
-
#ha_hosts ⇒ Array<String>
Optional.
-
#host_project ⇒ String
Required.
-
#region ⇒ String
Optional.
-
#replication_sites ⇒ Array<Google::Apis::WorkloadmanagerV1::SapDiscoveryComponentReplicationSite>
Optional.
-
#resources ⇒ Array<Google::Apis::WorkloadmanagerV1::SapDiscoveryResource>
Optional.
-
#sid ⇒ String
Optional.
-
#topology_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SapDiscoveryComponent
constructor
A new instance of SapDiscoveryComponent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SapDiscoveryComponent
Returns a new instance of SapDiscoveryComponent.
2698 2699 2700 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2698 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application_properties ⇒ Google::Apis::WorkloadmanagerV1::SapDiscoveryComponentApplicationProperties
A set of properties describing an SAP Application layer.
Corresponds to the JSON property applicationProperties
2653 2654 2655 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2653 def application_properties @application_properties end |
#database_properties ⇒ Google::Apis::WorkloadmanagerV1::SapDiscoveryComponentDatabaseProperties
A set of properties describing an SAP Database layer.
Corresponds to the JSON property databaseProperties
2658 2659 2660 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2658 def database_properties @database_properties end |
#ha_hosts ⇒ Array<String>
Optional. A list of host URIs that are part of the HA configuration if present.
An empty list indicates the component is not configured for HA.
Corresponds to the JSON property haHosts
2664 2665 2666 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2664 def ha_hosts @ha_hosts end |
#host_project ⇒ String
Required. Pantheon Project in which the resources reside.
Corresponds to the JSON property hostProject
2669 2670 2671 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2669 def host_project @host_project end |
#region ⇒ String
Optional. The region this component's resources are primarily located in.
Corresponds to the JSON property region
2674 2675 2676 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2674 def region @region end |
#replication_sites ⇒ Array<Google::Apis::WorkloadmanagerV1::SapDiscoveryComponentReplicationSite>
Optional. A list of replication sites used in Disaster Recovery (DR)
configurations.
Corresponds to the JSON property replicationSites
2680 2681 2682 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2680 def replication_sites @replication_sites end |
#resources ⇒ Array<Google::Apis::WorkloadmanagerV1::SapDiscoveryResource>
Optional. The resources in a component.
Corresponds to the JSON property resources
2685 2686 2687 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2685 def resources @resources end |
#sid ⇒ String
Optional. The SAP identifier, used by the SAP software and helps differentiate
systems for customers.
Corresponds to the JSON property sid
2691 2692 2693 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2691 def sid @sid end |
#topology_type ⇒ String
Optional. The detected topology of the component.
Corresponds to the JSON property topologyType
2696 2697 2698 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2696 def topology_type @topology_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2703 def update!(**args) @application_properties = args[:application_properties] if args.key?(:application_properties) @database_properties = args[:database_properties] if args.key?(:database_properties) @ha_hosts = args[:ha_hosts] if args.key?(:ha_hosts) @host_project = args[:host_project] if args.key?(:host_project) @region = args[:region] if args.key?(:region) @replication_sites = args[:replication_sites] if args.key?(:replication_sites) @resources = args[:resources] if args.key?(:resources) @sid = args[:sid] if args.key?(:sid) @topology_type = args[:topology_type] if args.key?(:topology_type) end |