Class: Google::Apis::WorkloadmanagerV1::SapDiscoveryComponent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Message describing the system component.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SapDiscoveryComponent

Returns a new instance of SapDiscoveryComponent.



2696
2697
2698
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_propertiesGoogle::Apis::WorkloadmanagerV1::SapDiscoveryComponentApplicationProperties

A set of properties describing an SAP Application layer. Corresponds to the JSON property applicationProperties



2651
2652
2653
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2651

def application_properties
  @application_properties
end

#database_propertiesGoogle::Apis::WorkloadmanagerV1::SapDiscoveryComponentDatabaseProperties

A set of properties describing an SAP Database layer. Corresponds to the JSON property databaseProperties



2656
2657
2658
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2656

def database_properties
  @database_properties
end

#ha_hostsArray<String>

Optional. A list of host URIs that are part of the HA configuration if present. An empty list indicates the component is not configured for HA. Corresponds to the JSON property haHosts

Returns:

  • (Array<String>)


2662
2663
2664
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2662

def ha_hosts
  @ha_hosts
end

#host_projectString

Required. Pantheon Project in which the resources reside. Corresponds to the JSON property hostProject

Returns:

  • (String)


2667
2668
2669
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2667

def host_project
  @host_project
end

#regionString

Optional. The region this component's resources are primarily located in. Corresponds to the JSON property region

Returns:

  • (String)


2672
2673
2674
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2672

def region
  @region
end

#replication_sitesArray<Google::Apis::WorkloadmanagerV1::SapDiscoveryComponentReplicationSite>

Optional. A list of replication sites used in Disaster Recovery (DR) configurations. Corresponds to the JSON property replicationSites



2678
2679
2680
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2678

def replication_sites
  @replication_sites
end

#resourcesArray<Google::Apis::WorkloadmanagerV1::SapDiscoveryResource>

Optional. The resources in a component. Corresponds to the JSON property resources



2683
2684
2685
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2683

def resources
  @resources
end

#sidString

Optional. The SAP identifier, used by the SAP software and helps differentiate systems for customers. Corresponds to the JSON property sid

Returns:

  • (String)


2689
2690
2691
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2689

def sid
  @sid
end

#topology_typeString

Optional. The detected topology of the component. Corresponds to the JSON property topologyType

Returns:

  • (String)


2694
2695
2696
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2694

def topology_type
  @topology_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2701
2702
2703
2704
2705
2706
2707
2708
2709
2710
2711
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2701

def update!(**args)
  @application_properties = args[:application_properties] if args.key?(:application_properties)
  @database_properties = args[:database_properties] if args.key?(:database_properties)
  @ha_hosts = args[:ha_hosts] if args.key?(:ha_hosts)
  @host_project = args[:host_project] if args.key?(:host_project)
  @region = args[:region] if args.key?(:region)
  @replication_sites = args[:replication_sites] if args.key?(:replication_sites)
  @resources = args[:resources] if args.key?(:resources)
  @sid = args[:sid] if args.key?(:sid)
  @topology_type = args[:topology_type] if args.key?(:topology_type)
end