Class: Google::Apis::WorkloadmanagerV1::SapDiscoveryComponentDatabaseProperties
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::SapDiscoveryComponentDatabaseProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
A set of properties describing an SAP Database layer.
Instance Attribute Summary collapse
-
#database_sid ⇒ String
Optional.
-
#database_type ⇒ String
Required.
-
#database_version ⇒ String
Optional.
-
#instance_number ⇒ String
Optional.
-
#landscape_id ⇒ String
Optional.
-
#primary_instance_uri ⇒ String
Required.
-
#shared_nfs_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SapDiscoveryComponentDatabaseProperties
constructor
A new instance of SapDiscoveryComponentDatabaseProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SapDiscoveryComponentDatabaseProperties
Returns a new instance of SapDiscoveryComponentDatabaseProperties.
2820 2821 2822 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2820 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database_sid ⇒ String
Optional. SID of the system database.
Corresponds to the JSON property databaseSid
2787 2788 2789 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2787 def database_sid @database_sid end |
#database_type ⇒ String
Required. Type of the database. HANA, DB2, etc.
Corresponds to the JSON property databaseType
2792 2793 2794 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2792 def database_type @database_type end |
#database_version ⇒ String
Optional. The version of the database software running in the system.
Corresponds to the JSON property databaseVersion
2797 2798 2799 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2797 def database_version @database_version end |
#instance_number ⇒ String
Optional. Instance number of the SAP instance.
Corresponds to the JSON property instanceNumber
2802 2803 2804 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2802 def instance_number @instance_number end |
#landscape_id ⇒ String
Optional. Landscape ID from the HANA nameserver.
Corresponds to the JSON property landscapeId
2807 2808 2809 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2807 def landscape_id @landscape_id end |
#primary_instance_uri ⇒ String
Required. URI of the recognized primary instance of the database.
Corresponds to the JSON property primaryInstanceUri
2812 2813 2814 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2812 def primary_instance_uri @primary_instance_uri end |
#shared_nfs_uri ⇒ String
Optional. URI of the recognized shared NFS of the database. May be empty if
the database has only a single node.
Corresponds to the JSON property sharedNfsUri
2818 2819 2820 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2818 def shared_nfs_uri @shared_nfs_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2825 def update!(**args) @database_sid = args[:database_sid] if args.key?(:database_sid) @database_type = args[:database_type] if args.key?(:database_type) @database_version = args[:database_version] if args.key?(:database_version) @instance_number = args[:instance_number] if args.key?(:instance_number) @landscape_id = args[:landscape_id] if args.key?(:landscape_id) @primary_instance_uri = args[:primary_instance_uri] if args.key?(:primary_instance_uri) @shared_nfs_uri = args[:shared_nfs_uri] if args.key?(:shared_nfs_uri) end |