Class: Google::Apis::WorkloadmanagerV1::SapDiscoveryComponentDatabaseProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

A set of properties describing an SAP Database layer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SapDiscoveryComponentDatabaseProperties

Returns a new instance of SapDiscoveryComponentDatabaseProperties.



2818
2819
2820
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_sidString

Optional. SID of the system database. Corresponds to the JSON property databaseSid

Returns:

  • (String)


2785
2786
2787
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2785

def database_sid
  @database_sid
end

#database_typeString

Required. Type of the database. HANA, DB2, etc. Corresponds to the JSON property databaseType

Returns:

  • (String)


2790
2791
2792
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2790

def database_type
  @database_type
end

#database_versionString

Optional. The version of the database software running in the system. Corresponds to the JSON property databaseVersion

Returns:

  • (String)


2795
2796
2797
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2795

def database_version
  @database_version
end

#instance_numberString

Optional. Instance number of the SAP instance. Corresponds to the JSON property instanceNumber

Returns:

  • (String)


2800
2801
2802
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2800

def instance_number
  @instance_number
end

#landscape_idString

Optional. Landscape ID from the HANA nameserver. Corresponds to the JSON property landscapeId

Returns:

  • (String)


2805
2806
2807
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2805

def landscape_id
  @landscape_id
end

#primary_instance_uriString

Required. URI of the recognized primary instance of the database. Corresponds to the JSON property primaryInstanceUri

Returns:

  • (String)


2810
2811
2812
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2810

def primary_instance_uri
  @primary_instance_uri
end

#shared_nfs_uriString

Optional. URI of the recognized shared NFS of the database. May be empty if the database has only a single node. Corresponds to the JSON property sharedNfsUri

Returns:

  • (String)


2816
2817
2818
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2816

def shared_nfs_uri
  @shared_nfs_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2823

def update!(**args)
  @database_sid = args[:database_sid] if args.key?(:database_sid)
  @database_type = args[:database_type] if args.key?(:database_type)
  @database_version = args[:database_version] if args.key?(:database_version)
  @instance_number = args[:instance_number] if args.key?(:instance_number)
  @landscape_id = args[:landscape_id] if args.key?(:landscape_id)
  @primary_instance_uri = args[:primary_instance_uri] if args.key?(:primary_instance_uri)
  @shared_nfs_uri = args[:shared_nfs_uri] if args.key?(:shared_nfs_uri)
end