Class: Google::Apis::WorkloadmanagerV1::SapDiscoveryResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Message describing a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SapDiscoveryResource

Returns a new instance of SapDiscoveryResource.



2932
2933
2934
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_propertiesGoogle::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstanceProperties

A set of properties only present for an instance type resource Corresponds to the JSON property instanceProperties



2904
2905
2906
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2904

def instance_properties
  @instance_properties
end

Optional. A list of resource URIs related to this resource. Corresponds to the JSON property relatedResources

Returns:

  • (Array<String>)


2909
2910
2911
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2909

def related_resources
  @related_resources
end

#resource_kindString

Required. ComputeInstance, ComputeDisk, VPC, Bare Metal server, etc. Corresponds to the JSON property resourceKind

Returns:

  • (String)


2914
2915
2916
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2914

def resource_kind
  @resource_kind
end

#resource_typeString

Required. The type of this resource. Corresponds to the JSON property resourceType

Returns:

  • (String)


2919
2920
2921
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2919

def resource_type
  @resource_type
end

#resource_uriString

Required. URI of the resource, includes project, location, and name. Corresponds to the JSON property resourceUri

Returns:

  • (String)


2924
2925
2926
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2924

def resource_uri
  @resource_uri
end

#update_timeString

Required. Unix timestamp of when this resource last had its discovery data updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2930
2931
2932
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2930

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2937
2938
2939
2940
2941
2942
2943
2944
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2937

def update!(**args)
  @instance_properties = args[:instance_properties] if args.key?(:instance_properties)
  @related_resources = args[:related_resources] if args.key?(:related_resources)
  @resource_kind = args[:resource_kind] if args.key?(:resource_kind)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @update_time = args[:update_time] if args.key?(:update_time)
end