Class: Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstanceProperties
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstanceProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
A set of properties only present for an instance type resource
Instance Attribute Summary collapse
-
#app_instances ⇒ Array<Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesAppInstance>
Optional.
-
#cluster_instances ⇒ Array<String>
Optional.
-
#disk_mounts ⇒ Array<Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesDiskMount>
Optional.
-
#instance_number ⇒ Fixnum
Optional.
-
#instance_role ⇒ String
Optional.
-
#is_dr_site ⇒ Boolean
(also: #is_dr_site?)
Optional.
-
#os_kernel_version ⇒ Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesKernelVersion
KernelVersion encapsulates the kernel version data for the system.
-
#virtual_hostname ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SapDiscoveryResourceInstanceProperties
constructor
A new instance of SapDiscoveryResourceInstanceProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SapDiscoveryResourceInstanceProperties
Returns a new instance of SapDiscoveryResourceInstanceProperties.
2992 2993 2994 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_instances ⇒ Array<Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesAppInstance>
Optional. App server instances on the host
Corresponds to the JSON property appInstances
2954 2955 2956 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2954 def app_instances @app_instances end |
#cluster_instances ⇒ Array<String>
Optional. A list of instance URIs that are part of a cluster with this one.
Corresponds to the JSON property clusterInstances
2959 2960 2961 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2959 def cluster_instances @cluster_instances end |
#disk_mounts ⇒ Array<Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesDiskMount>
Optional. Disk mounts on the instance.
Corresponds to the JSON property diskMounts
2964 2965 2966 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2964 def disk_mounts @disk_mounts end |
#instance_number ⇒ Fixnum
Optional. The VM's instance number.
Corresponds to the JSON property instanceNumber
2969 2970 2971 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2969 def instance_number @instance_number end |
#instance_role ⇒ String
Optional. Bitmask of instance role, a resource may have multiple roles at once.
Corresponds to the JSON property instanceRole
2974 2975 2976 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2974 def instance_role @instance_role end |
#is_dr_site ⇒ Boolean Also known as: is_dr_site?
Optional. Instance is part of a DR site.
Corresponds to the JSON property isDrSite
2979 2980 2981 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2979 def is_dr_site @is_dr_site end |
#os_kernel_version ⇒ Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesKernelVersion
KernelVersion encapsulates the kernel version data for the system.
Corresponds to the JSON property osKernelVersion
2985 2986 2987 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2985 def os_kernel_version @os_kernel_version end |
#virtual_hostname ⇒ String
Optional. A virtual hostname of the instance if it has one.
Corresponds to the JSON property virtualHostname
2990 2991 2992 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2990 def virtual_hostname @virtual_hostname end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 2997 def update!(**args) @app_instances = args[:app_instances] if args.key?(:app_instances) @cluster_instances = args[:cluster_instances] if args.key?(:cluster_instances) @disk_mounts = args[:disk_mounts] if args.key?(:disk_mounts) @instance_number = args[:instance_number] if args.key?(:instance_number) @instance_role = args[:instance_role] if args.key?(:instance_role) @is_dr_site = args[:is_dr_site] if args.key?(:is_dr_site) @os_kernel_version = args[:os_kernel_version] if args.key?(:os_kernel_version) @virtual_hostname = args[:virtual_hostname] if args.key?(:virtual_hostname) end |