Class: Google::Apis::WorkloadmanagerV1::SapDiscoveryResourceInstancePropertiesKernelVersionVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Version is reported as Major.Minor.Build.Patch.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SapDiscoveryResourceInstancePropertiesKernelVersionVersion

Returns a new instance of SapDiscoveryResourceInstancePropertiesKernelVersionVersion.



3126
3127
3128
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#buildFixnum

Optional. The build version number. Corresponds to the JSON property build

Returns:

  • (Fixnum)


3103
3104
3105
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3103

def build
  @build
end

#majorFixnum

Optional. The major version number. Corresponds to the JSON property major

Returns:

  • (Fixnum)


3108
3109
3110
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3108

def major
  @major
end

#minorFixnum

Optional. The minor version number. Corresponds to the JSON property minor

Returns:

  • (Fixnum)


3113
3114
3115
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3113

def minor
  @minor
end

#patchFixnum

Optional. The patch version number. Corresponds to the JSON property patch

Returns:

  • (Fixnum)


3118
3119
3120
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3118

def patch
  @patch
end

#remainderString

Optional. A catch-all for any unparsed version components. This is in case the number of points in the version string exceeds the expected count of 4. Corresponds to the JSON property remainder

Returns:

  • (String)


3124
3125
3126
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3124

def remainder
  @remainder
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3131
3132
3133
3134
3135
3136
3137
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3131

def update!(**args)
  @build = args[:build] if args.key?(:build)
  @major = args[:major] if args.key?(:major)
  @minor = args[:minor] if args.key?(:minor)
  @patch = args[:patch] if args.key?(:patch)
  @remainder = args[:remainder] if args.key?(:remainder)
end