Class: Google::Apis::WorkloadmanagerV1::SapSystemS4Config
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::SapSystemS4Config
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
Message for sap system workload
Instance Attribute Summary collapse
-
#allow_stopping_for_update ⇒ Boolean
(also: #allow_stopping_for_update?)
Corresponds to the JSON property
allowStoppingForUpdate. -
#ansible_runner_service_account ⇒ String
Ansible runner service account - let custoemrs bring their own SA for Ansible runner Corresponds to the JSON property
ansibleRunnerServiceAccount. -
#app ⇒ Google::Apis::WorkloadmanagerV1::AppDetails
Message for sap instant details Corresponds to the JSON property
app. -
#database ⇒ Google::Apis::WorkloadmanagerV1::DatabaseDetails
Message for sap instant details Corresponds to the JSON property
database. -
#deployment_model ⇒ String
Required.
-
#environment_type ⇒ String
Required.
-
#gcp_project_id ⇒ String
the project that infrastructure deployed, current only support the same project where the deployment resource exist.
-
#location ⇒ Google::Apis::WorkloadmanagerV1::LocationDetails
Message for sap instant details Corresponds to the JSON property
location. -
#media_bucket_name ⇒ String
Required.
-
#sap_boot_disk_image ⇒ String
Optional.
-
#scaling_method ⇒ String
Required.
-
#version ⇒ String
Required.
-
#vm_prefix ⇒ String
vm_prefix Corresponds to the JSON property
vmPrefix.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SapSystemS4Config
constructor
A new instance of SapSystemS4Config.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SapSystemS4Config
Returns a new instance of SapSystemS4Config.
3325 3326 3327 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_stopping_for_update ⇒ Boolean Also known as: allow_stopping_for_update?
Corresponds to the JSON property allowStoppingForUpdate
3260 3261 3262 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3260 def allow_stopping_for_update @allow_stopping_for_update end |
#ansible_runner_service_account ⇒ String
Ansible runner service account - let custoemrs bring their own SA for Ansible
runner
Corresponds to the JSON property ansibleRunnerServiceAccount
3267 3268 3269 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3267 def ansible_runner_service_account @ansible_runner_service_account end |
#app ⇒ Google::Apis::WorkloadmanagerV1::AppDetails
Message for sap instant details
Corresponds to the JSON property app
3272 3273 3274 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3272 def app @app end |
#database ⇒ Google::Apis::WorkloadmanagerV1::DatabaseDetails
Message for sap instant details
Corresponds to the JSON property database
3277 3278 3279 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3277 def database @database end |
#deployment_model ⇒ String
Required. two model non-HA and HA supported
Corresponds to the JSON property deploymentModel
3282 3283 3284 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3282 def deployment_model @deployment_model end |
#environment_type ⇒ String
Required. deployment environment
Corresponds to the JSON property environmentType
3287 3288 3289 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3287 def environment_type @environment_type end |
#gcp_project_id ⇒ String
the project that infrastructure deployed, current only support the same
project where the deployment resource exist.
Corresponds to the JSON property gcpProjectId
3293 3294 3295 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3293 def gcp_project_id @gcp_project_id end |
#location ⇒ Google::Apis::WorkloadmanagerV1::LocationDetails
Message for sap instant details
Corresponds to the JSON property location
3298 3299 3300 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3298 def location @location end |
#media_bucket_name ⇒ String
Required. media_bucket_name
Corresponds to the JSON property mediaBucketName
3303 3304 3305 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3303 def media_bucket_name @media_bucket_name end |
#sap_boot_disk_image ⇒ String
Optional. sap_boot_disk_image
Corresponds to the JSON property sapBootDiskImage
3308 3309 3310 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3308 def sap_boot_disk_image @sap_boot_disk_image end |
#scaling_method ⇒ String
Required. support scale up and scale out
Corresponds to the JSON property scalingMethod
3313 3314 3315 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3313 def scaling_method @scaling_method end |
#version ⇒ String
Required. sap hana version
Corresponds to the JSON property version
3318 3319 3320 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3318 def version @version end |
#vm_prefix ⇒ String
vm_prefix
Corresponds to the JSON property vmPrefix
3323 3324 3325 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3323 def vm_prefix @vm_prefix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 3340 3341 3342 3343 3344 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3330 def update!(**args) @allow_stopping_for_update = args[:allow_stopping_for_update] if args.key?(:allow_stopping_for_update) @ansible_runner_service_account = args[:ansible_runner_service_account] if args.key?(:ansible_runner_service_account) @app = args[:app] if args.key?(:app) @database = args[:database] if args.key?(:database) @deployment_model = args[:deployment_model] if args.key?(:deployment_model) @environment_type = args[:environment_type] if args.key?(:environment_type) @gcp_project_id = args[:gcp_project_id] if args.key?(:gcp_project_id) @location = args[:location] if args.key?(:location) @media_bucket_name = args[:media_bucket_name] if args.key?(:media_bucket_name) @sap_boot_disk_image = args[:sap_boot_disk_image] if args.key?(:sap_boot_disk_image) @scaling_method = args[:scaling_method] if args.key?(:scaling_method) @version = args[:version] if args.key?(:version) @vm_prefix = args[:vm_prefix] if args.key?(:vm_prefix) end |