Class: Google::Apis::WorkloadmanagerV1::SapWorkload
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::SapWorkload
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
The body of sap workload
Instance Attribute Summary collapse
-
#application ⇒ Google::Apis::WorkloadmanagerV1::SapComponent
The component of sap workload Corresponds to the JSON property
application. -
#architecture ⇒ String
Output only.
-
#database ⇒ Google::Apis::WorkloadmanagerV1::SapComponent
The component of sap workload Corresponds to the JSON property
database. -
#metadata ⇒ Hash<String,String>
Output only.
-
#products ⇒ Array<Google::Apis::WorkloadmanagerV1::Product>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SapWorkload
constructor
A new instance of SapWorkload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SapWorkload
Returns a new instance of SapWorkload.
3440 3441 3442 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application ⇒ Google::Apis::WorkloadmanagerV1::SapComponent
The component of sap workload
Corresponds to the JSON property application
3418 3419 3420 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3418 def application @application end |
#architecture ⇒ String
Output only. The architecture.
Corresponds to the JSON property architecture
3423 3424 3425 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3423 def architecture @architecture end |
#database ⇒ Google::Apis::WorkloadmanagerV1::SapComponent
The component of sap workload
Corresponds to the JSON property database
3428 3429 3430 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3428 def database @database end |
#metadata ⇒ Hash<String,String>
Output only. The metadata for SAP workload.
Corresponds to the JSON property metadata
3433 3434 3435 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3433 def @metadata end |
#products ⇒ Array<Google::Apis::WorkloadmanagerV1::Product>
Output only. The products on this workload.
Corresponds to the JSON property products
3438 3439 3440 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3438 def products @products end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3445 3446 3447 3448 3449 3450 3451 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3445 def update!(**args) @application = args[:application] if args.key?(:application) @architecture = args[:architecture] if args.key?(:architecture) @database = args[:database] if args.key?(:database) @metadata = args[:metadata] if args.key?(:metadata) @products = args[:products] if args.key?(:products) end |