Class: Google::Apis::WorkloadmanagerV1::SqlLocationDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Location and networking details for configuring SQL server workload

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlLocationDetails

Returns a new instance of SqlLocationDetails.



3589
3590
3591
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_zoneString

Optional. create a new DNS Zone when the field is empty, Only show for Using an existing DNS List of existing DNS Zones tf variable name: existing_dns_zone_name Corresponds to the JSON property dnsZone

Returns:

  • (String)


3544
3545
3546
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3544

def dns_zone
  @dns_zone
end

#gcp_project_idString

Required. the project that infrastructure deployed, currently only supports the same project where the deployment resource exists. Corresponds to the JSON property gcpProjectId

Returns:

  • (String)


3550
3551
3552
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3550

def gcp_project_id
  @gcp_project_id
end

#internet_accessString

Required. Internet Access Corresponds to the JSON property internetAccess

Returns:

  • (String)


3555
3556
3557
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3555

def internet_access
  @internet_access
end

#networkString

Required. network name Corresponds to the JSON property network

Returns:

  • (String)


3560
3561
3562
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3560

def network
  @network
end

#primary_zoneString

Required. primary zone Corresponds to the JSON property primaryZone

Returns:

  • (String)


3565
3566
3567
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3565

def primary_zone
  @primary_zone
end

#regionString

Required. region name Corresponds to the JSON property region

Returns:

  • (String)


3570
3571
3572
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3570

def region
  @region
end

#secondary_zoneString

Optional. secondary zone can't be same as primary_zone and is only for High Availability deployment mode Corresponds to the JSON property secondaryZone

Returns:

  • (String)


3576
3577
3578
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3576

def secondary_zone
  @secondary_zone
end

#subnetworkString

Required. subnetwork name Corresponds to the JSON property subnetwork

Returns:

  • (String)


3581
3582
3583
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3581

def subnetwork
  @subnetwork
end

#tertiary_zoneString

Optional. teriary zone can't be same as primary_zone and secondary zone, and it is only for High Availability deployment mode Corresponds to the JSON property tertiaryZone

Returns:

  • (String)


3587
3588
3589
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3587

def tertiary_zone
  @tertiary_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3594
3595
3596
3597
3598
3599
3600
3601
3602
3603
3604
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3594

def update!(**args)
  @dns_zone = args[:dns_zone] if args.key?(:dns_zone)
  @gcp_project_id = args[:gcp_project_id] if args.key?(:gcp_project_id)
  @internet_access = args[:internet_access] if args.key?(:internet_access)
  @network = args[:network] if args.key?(:network)
  @primary_zone = args[:primary_zone] if args.key?(:primary_zone)
  @region = args[:region] if args.key?(:region)
  @secondary_zone = args[:secondary_zone] if args.key?(:secondary_zone)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @tertiary_zone = args[:tertiary_zone] if args.key?(:tertiary_zone)
end