Class: Google::Apis::WorkloadmanagerV1::SqlServerWorkload

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Message for MS SQL workload

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerWorkload

Returns a new instance of SqlServerWorkload.



3702
3703
3704
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_directoryGoogle::Apis::WorkloadmanagerV1::ActiveDirectory

Active directory details Corresponds to the JSON property activeDirectory



3614
3615
3616
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3614

def active_directory
  @active_directory
end

#compute_engine_service_accountString

Compute engine service account - let customers bring their own SA for Compute engine Corresponds to the JSON property computeEngineServiceAccount

Returns:

  • (String)


3620
3621
3622
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3620

def 
  @compute_engine_service_account
end

#databaseGoogle::Apis::WorkloadmanagerV1::Database

Database details Corresponds to the JSON property database



3625
3626
3627
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3625

def database
  @database
end

#deployment_modelString

Required. HIGH_AVAILABILITY or SINGLE_INSTANCE Corresponds to the JSON property deploymentModel

Returns:

  • (String)


3630
3631
3632
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3630

def deployment_model
  @deployment_model
end

#environment_typeString

Required. deployment environment Corresponds to the JSON property environmentType

Returns:

  • (String)


3635
3636
3637
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3635

def environment_type
  @environment_type
end

#fci_typeString

Optional. SHARED_DISK or S2D Corresponds to the JSON property fciType

Returns:

  • (String)


3640
3641
3642
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3640

def fci_type
  @fci_type
end

#ha_typeString

Optional. AOAG or FCI, it is only needed for High Availability deployment mode Corresponds to the JSON property haType

Returns:

  • (String)


3645
3646
3647
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3645

def ha_type
  @ha_type
end

#is_sql_paygBoolean Also known as: is_sql_payg?

Required. SQL licensing type Corresponds to the JSON property isSqlPayg

Returns:

  • (Boolean)


3650
3651
3652
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3650

def is_sql_payg
  @is_sql_payg
end

#locationGoogle::Apis::WorkloadmanagerV1::SqlLocationDetails

Location and networking details for configuring SQL server workload Corresponds to the JSON property location



3656
3657
3658
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3656

def location
  @location
end

#media_bucketString

Required. name of the media storing SQL server installation files Corresponds to the JSON property mediaBucket

Returns:

  • (String)


3661
3662
3663
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3661

def media_bucket
  @media_bucket
end

#operating_system_typeString

Required. type of the operating system the SQL server is going to run on top of Corresponds to the JSON property operatingSystemType

Returns:

  • (String)


3667
3668
3669
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3667

def operating_system_type
  @operating_system_type
end

#os_imageString

Required. the image of the operating system Corresponds to the JSON property osImage

Returns:

  • (String)


3672
3673
3674
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3672

def os_image
  @os_image
end

#os_image_typeString

Optional. OS image type, it's used to create boot disks for VM instances When either Windows licensing type or SQL licensing type is BYOL, this option is disabled and default to custom image Corresponds to the JSON property osImageType

Returns:

  • (String)


3679
3680
3681
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3679

def os_image_type
  @os_image_type
end

#pacemakerGoogle::Apis::WorkloadmanagerV1::Pacemaker

pacemaker configuration Corresponds to the JSON property pacemaker



3684
3685
3686
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3684

def pacemaker
  @pacemaker
end

#sql_server_editionString

Optional. SQL Server Edition type, only applicable when Operating System is Linux Corresponds to the JSON property sqlServerEdition

Returns:

  • (String)


3690
3691
3692
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3690

def sql_server_edition
  @sql_server_edition
end

#sql_server_versionString

Optional. 2017 or 2019 or 2022 Corresponds to the JSON property sqlServerVersion

Returns:

  • (String)


3695
3696
3697
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3695

def sql_server_version
  @sql_server_version
end

#vm_prefixString

Required. should be unique in the project Corresponds to the JSON property vmPrefix

Returns:

  • (String)


3700
3701
3702
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3700

def vm_prefix
  @vm_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3707

def update!(**args)
  @active_directory = args[:active_directory] if args.key?(:active_directory)
  @compute_engine_service_account = args[:compute_engine_service_account] if args.key?(:compute_engine_service_account)
  @database = args[:database] if args.key?(:database)
  @deployment_model = args[:deployment_model] if args.key?(:deployment_model)
  @environment_type = args[:environment_type] if args.key?(:environment_type)
  @fci_type = args[:fci_type] if args.key?(:fci_type)
  @ha_type = args[:ha_type] if args.key?(:ha_type)
  @is_sql_payg = args[:is_sql_payg] if args.key?(:is_sql_payg)
  @location = args[:location] if args.key?(:location)
  @media_bucket = args[:media_bucket] if args.key?(:media_bucket)
  @operating_system_type = args[:operating_system_type] if args.key?(:operating_system_type)
  @os_image = args[:os_image] if args.key?(:os_image)
  @os_image_type = args[:os_image_type] if args.key?(:os_image_type)
  @pacemaker = args[:pacemaker] if args.key?(:pacemaker)
  @sql_server_edition = args[:sql_server_edition] if args.key?(:sql_server_edition)
  @sql_server_version = args[:sql_server_version] if args.key?(:sql_server_version)
  @vm_prefix = args[:vm_prefix] if args.key?(:vm_prefix)
end