Class: Google::Apis::WorkloadmanagerV1::Summary
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::Summary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
Execution summary.
Instance Attribute Summary collapse
-
#failures ⇒ Fixnum
Output only.
-
#new_failures ⇒ Fixnum
Output only.
-
#new_fixes ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Summary
constructor
A new instance of Summary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Summary
Returns a new instance of Summary.
3870 3871 3872 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3870 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failures ⇒ Fixnum
Output only. Number of failures.
Corresponds to the JSON property failures
3858 3859 3860 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3858 def failures @failures end |
#new_failures ⇒ Fixnum
Output only. Number of new failures compared to the previous execution.
Corresponds to the JSON property newFailures
3863 3864 3865 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3863 def new_failures @new_failures end |
#new_fixes ⇒ Fixnum
Output only. Number of new fixes compared to the previous execution.
Corresponds to the JSON property newFixes
3868 3869 3870 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3868 def new_fixes @new_fixes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3875 3876 3877 3878 3879 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3875 def update!(**args) @failures = args[:failures] if args.key?(:failures) @new_failures = args[:new_failures] if args.key?(:new_failures) @new_fixes = args[:new_fixes] if args.key?(:new_fixes) end |