Class: Google::Apis::WorkloadmanagerV1::TerraformVariable
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::TerraformVariable
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
In order to align with the Infra Manager dependency, we create the same TerraformVariable message to represent a Terraform input variable, by following Infra Manager's API documentation: https://cloud.google.com/ infrastructure-manager/docs/reference/rest. A Terraform input variable.
Instance Attribute Summary collapse
-
#input_value ⇒ Object
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TerraformVariable
constructor
A new instance of TerraformVariable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TerraformVariable
Returns a new instance of TerraformVariable.
3897 3898 3899 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3897 def initialize(**args) update!(**args) end |
Instance Attribute Details
#input_value ⇒ Object
Optional. Input variable value.
Corresponds to the JSON property inputValue
3895 3896 3897 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3895 def input_value @input_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3902 3903 3904 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3902 def update!(**args) @input_value = args[:input_value] if args.key?(:input_value) end |