Class: Google::Apis::WorkloadmanagerV1::TerraformVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

In order to align with Infra Manager dependency, we create the same TerraformVariable message to represent a Terraform input variable, by following Infra Manager's API documentation: https://cloud.google.com/ infrastructure-manager/docs/reference/rest A Terraform input variable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TerraformVariable

Returns a new instance of TerraformVariable.



3894
3895
3896
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#input_valueObject

Optional. Input variable value. Corresponds to the JSON property inputValue

Returns:

  • (Object)


3892
3893
3894
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3892

def input_value
  @input_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3899
3900
3901
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3899

def update!(**args)
  @input_value = args[:input_value] if args.key?(:input_value)
end