Class: Google::Apis::WorkloadmanagerV1::TorsoValidation
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::TorsoValidation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
The schema of torso workload validation data.
Instance Attribute Summary collapse
-
#agent_version ⇒ String
Required.
-
#instance_name ⇒ String
Optional.
-
#project_id ⇒ String
Required.
-
#validation_details ⇒ Hash<String,String>
Required.
-
#workload_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TorsoValidation
constructor
A new instance of TorsoValidation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TorsoValidation
Returns a new instance of TorsoValidation.
3937 3938 3939 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_version ⇒ String
Required. agent_version lists the version of the agent that collected this
data.
Corresponds to the JSON property agentVersion
3912 3913 3914 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3912 def agent_version @agent_version end |
#instance_name ⇒ String
Optional. instance_name lists the human readable name of the instance that the
data comes from.
Corresponds to the JSON property instanceName
3918 3919 3920 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3918 def instance_name @instance_name end |
#project_id ⇒ String
Required. project_id lists the human readable cloud project that the data
comes from.
Corresponds to the JSON property projectId
3924 3925 3926 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3924 def project_id @project_id end |
#validation_details ⇒ Hash<String,String>
Required. validation_details contains the pairs of validation data: field name
& field value.
Corresponds to the JSON property validationDetails
3930 3931 3932 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3930 def validation_details @validation_details end |
#workload_type ⇒ String
Required. workload_type specifies the type of torso workload.
Corresponds to the JSON property workloadType
3935 3936 3937 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3935 def workload_type @workload_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3942 3943 3944 3945 3946 3947 3948 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 3942 def update!(**args) @agent_version = args[:agent_version] if args.key?(:agent_version) @instance_name = args[:instance_name] if args.key?(:instance_name) @project_id = args[:project_id] if args.key?(:project_id) @validation_details = args[:validation_details] if args.key?(:validation_details) @workload_type = args[:workload_type] if args.key?(:workload_type) end |