Class: Google::Apis::WorkloadmanagerV1::WorkloadProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb

Overview

Workload resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadProfile

Returns a new instance of WorkloadProfile.



4062
4063
4064
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Optional. such as name, description, version. More example can be found in deployment Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4039
4040
4041
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4039

def labels
  @labels
end

#nameString

Identifier. name of resource names have the form 'projects/project_id/ locations/location/workloadProfiles/workload_id' Corresponds to the JSON property name

Returns:

  • (String)


4045
4046
4047
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4045

def name
  @name
end

#refreshed_timeString

Required. time when the workload data was refreshed Corresponds to the JSON property refreshedTime

Returns:

  • (String)


4050
4051
4052
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4050

def refreshed_time
  @refreshed_time
end

#sap_workloadGoogle::Apis::WorkloadmanagerV1::SapWorkload

The body of sap workload Corresponds to the JSON property sapWorkload



4055
4056
4057
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4055

def sap_workload
  @sap_workload
end

#workload_typeString

Required. The type of the workload Corresponds to the JSON property workloadType

Returns:

  • (String)


4060
4061
4062
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4060

def workload_type
  @workload_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4067
4068
4069
4070
4071
4072
4073
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4067

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @refreshed_time = args[:refreshed_time] if args.key?(:refreshed_time)
  @sap_workload = args[:sap_workload] if args.key?(:sap_workload)
  @workload_type = args[:workload_type] if args.key?(:workload_type)
end