Class: Google::Apis::WorkloadmanagerV1::WriteInsightRequest
- Inherits:
-
Object
- Object
- Google::Apis::WorkloadmanagerV1::WriteInsightRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workloadmanager_v1/classes.rb,
lib/google/apis/workloadmanager_v1/representations.rb,
lib/google/apis/workloadmanager_v1/representations.rb
Overview
Request for sending the data insights.
Instance Attribute Summary collapse
-
#agent_version ⇒ String
Optional.
-
#insight ⇒ Google::Apis::WorkloadmanagerV1::Insight
A presentation of host resource usage where the workload runs.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WriteInsightRequest
constructor
A new instance of WriteInsightRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WriteInsightRequest
Returns a new instance of WriteInsightRequest.
4135 4136 4137 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_version ⇒ String
Optional. The agent version collected this data point.
Corresponds to the JSON property agentVersion
4114 4115 4116 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4114 def agent_version @agent_version end |
#insight ⇒ Google::Apis::WorkloadmanagerV1::Insight
A presentation of host resource usage where the workload runs.
Corresponds to the JSON property insight
4119 4120 4121 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4119 def insight @insight end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes since the first request. For example, consider a
situation where you make an initial request and the request times out. If you
make the request again with the same request ID, the server can check if
original operation with the same request ID was received, and if so, will
ignore the second request. This prevents clients from accidentally creating
duplicate commitments. The request ID must be a valid UUID with the exception
that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
4133 4134 4135 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4133 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4140 4141 4142 4143 4144 |
# File 'lib/google/apis/workloadmanager_v1/classes.rb', line 4140 def update!(**args) @agent_version = args[:agent_version] if args.key?(:agent_version) @insight = args[:insight] if args.key?(:insight) @request_id = args[:request_id] if args.key?(:request_id) end |